/* Copyright 2020 The ChromiumOS Authors
 * Use of this source code is governed by a BSD-style license that can be
 * found in the LICENSE file.
 */

#ifndef __CROS_EC_CONFIG_CHIP_H
#define __CROS_EC_CONFIG_CHIP_H

#include <zephyr/devicetree.h>
#include <zephyr/toolchain.h>

#define LID_ACCEL SENSOR_ID(DT_NODELABEL(lid_accel))

#define SENSOR_NODE DT_PATH(motionsense_sensor)
#define SENSOR_INFO_NODE DT_PATH(motionsense_sensor_info)
#define SENSOR_ALT_NODE DT_PATH(motionsense_sensor_alt)

/*
 * The battery enum is used in various drivers and these assume that it is
 * always available (defined in board.h). With Zephyr we don't include board.h
 * so we have a battery_enum.h header in the shim which defines
 * enum battery_type based on settings in the device tree. Include that here.
 */
#ifdef CONFIG_PLATFORM_EC_BATTERY
#include "battery_enum.h"
#endif

/*
 * This file translates Kconfig options to platform/ec options.
 *
 * Options which are from Zephyr platform/ec module (Kconfig) start
 * with CONFIG_PLATFORM_EC_, and can be found in the Kconfig file.
 *
 * Options which are for the platform/ec configuration can be found in
 * common/config.h.
 */

/*
 * Obsolete configs - these are options that are not needed, either because
 * Zephyr features directly replace the option, or because the config option
 * will not be used with Zephyr OS.
 */

/*
 * ROM resident support. The ROM resident capabilities in the Chromium OS
 * code are used with EC chipsets that provide more flash space than
 * executable RAM. These options allow storing the initialized data into
 * an unused area of flash where it is copied directly from flash into data
 * RAM by the early boot code.
 *
 * When ROM resident is disabled, the initialized data is stored in the main
 * image, copied from flash to executable RAM by the chip boot loader, and
 * then copied from executable RAM to data RAM by the early boot code.
 *
 * Supporting this under Zephyr would require linker changes to the common
 * Zephyr linking.
 */
#undef CONFIG_CHIP_DATA_IN_INIT_ROM
#undef CONFIG_CHIP_INIT_ROM_REGION
#undef CONFIG_RO_ROM_RESIDENT_MEM_OFF
#undef CONFIG_RO_ROM_RESIDENT_SIZE
#undef CONFIG_RW_ROM_RESIDENT_MEM_OFF
#undef CONFIG_RW_ROM_RESIDENT_SIZE

/*
 * ECOS specific options, not used in Zephyr.
 */
#undef CONFIG_BC12_SINGLE_DRIVER /* Obsolete due to BC1.2 shim driver */
#undef CONFIG_CONSOLE_UART /* Only used by the Chromium EC chip drivers */
#undef CONFIG_I2C_MULTI_PORT_CONTROLLER /* Not required by I2C shim */
#undef CONFIG_IRQ_COUNT /* Only used by Chromium EC core drivers */
#undef CONFIG_KEYBOARD_KSO_HIGH_DRIVE /* Used by the Chromium EC chip drivers \
				       */
#undef CONFIG_LTO /* Link time optimization enabled by Zephyr build system */
#undef CONFIG_STACK_SIZE /* Only used in Chromium EC core init code */
#ifndef CONFIG_FPU
#undef CONFIG_FPU /* Used in Zephyr as well, enabled in Kconfig directly */
#endif
#ifndef CONFIG_WATCHDOG
#undef CONFIG_WATCHDOG /* Used in Zephyr as well, enabled in Kconfig directly \
			*/
#endif

/*
 * The Zephyr I2C shell command provides the same functionality as the Chromium
 * EC i2cscan and i2cxfer commands, so they are always disabled.
 */
#undef CONFIG_CMD_I2C_SCAN
#undef CONFIG_CMD_I2C_XFER

/*
 * This not used by the Zephyr code since we always make cros_crc8() available.
 * Define it here to reduce the delta from the ECOS CONFIG.
 */
#undef CONFIG_CRC8
#define CONFIG_CRC8

/*
 * This is not used by the Zephyr code.
 * Define it here to reduce the delta from the ECOS CONFIG.
 */
#undef CONFIG_CHIP_PRE_INIT
#define CONFIG_CHIP_PRE_INIT

/* EC chipset configuration */
#define HOOK_TICK_INTERVAL CONFIG_CROS_EC_HOOK_TICK_INTERVAL
#define HOOK_TICK_INTERVAL_MS (HOOK_TICK_INTERVAL / 1000)

/* Chipset and power configuration */
#ifdef CONFIG_AP_ARM_QUALCOMM_SC7180
#define CONFIG_CHIPSET_SC7180
#endif

#ifdef CONFIG_AP_ARM_QUALCOMM_SC7280
#define CONFIG_CHIPSET_SC7280
#endif

#ifdef CONFIG_AP_X86_INTEL_CML
#define CONFIG_CHIPSET_COMETLAKE
#define CONFIG_CHIPSET_HAS_PRE_INIT_CALLBACK
#endif

#ifdef CONFIG_AP_X86_INTEL_TGL
#define CONFIG_CHIPSET_TIGERLAKE
#endif

#undef CONFIG_ALLOW_UNALIGNED_ACCESS
#ifdef CONFIG_PLATFORM_EC_ALLOW_UNALIGNED_ACCESS
#define CONFIG_ALLOW_UNALIGNED_ACCESS
#endif

#undef CONFIG_FLASH_PROTECT_DEFERRED
#ifdef CONFIG_PLATFORM_EC_FLASH_PROTECT_DEFERRED
#define CONFIG_FLASH_PROTECT_DEFERRED
#endif

#undef CONFIG_FLASH_DEFERRED_ERASE
#ifdef CONFIG_PLATFORM_EC_FLASH_DEFERRED_ERASE
#define CONFIG_FLASH_DEFERRED_ERASE
#endif

#undef CONFIG_THROTTLE_AP
#ifdef CONFIG_PLATFORM_EC_THROTTLE_AP
#define CONFIG_THROTTLE_AP
#endif

#undef CONFIG_THROTTLE_AP_SINGLE_PIN
#ifdef CONFIG_PLATFORM_EC_THROTTLE_AP_SINGLE_PIN
#define CONFIG_THROTTLE_AP_SINGLE_PIN
#endif

#undef CONFIG_THROTTLE_AP_NO_FAN
#ifdef CONFIG_PLATFORM_EC_THROTTLE_AP_NO_FAN
#define CONFIG_THROTTLE_AP_NO_FAN
#endif

#undef CONFIG_CHIPSET_CAN_THROTTLE
#ifdef CONFIG_PLATFORM_EC_CHIPSET_CAN_THROTTLE
#define CONFIG_CHIPSET_CAN_THROTTLE
#endif

#undef CONFIG_CMD_APTHROTTLE
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_APTHROTTLE
#define CONFIG_CMD_APTHROTTLE
#endif

#undef CONFIG_THROTTLE_AP_ON_BAT_DISCHG_CURRENT
#ifdef CONFIG_PLATFORM_EC_THROTTLE_AP_ON_BAT_DISCHG_CURRENT
#define CONFIG_THROTTLE_AP_ON_BAT_DISCHG_CURRENT
#endif

#undef CONFIG_THROTTLE_AP_ON_BAT_VOLTAGE
#ifdef CONFIG_PLATFORM_EC_THROTTLE_AP_ON_BAT_LOW_VOLTAGE
#define CONFIG_THROTTLE_AP_ON_BAT_VOLTAGE
#endif

#undef CONFIG_BACKLIGHT_LID
#ifdef CONFIG_PLATFORM_EC_BACKLIGHT_LID
#define CONFIG_BACKLIGHT_LID
#endif

#undef CONFIG_BACKLIGHT_LID_ACTIVE_LOW
#ifdef CONFIG_PLATFORM_EC_BACKLIGHT_LID_ACTIVE_LOW
#define CONFIG_BACKLIGHT_LID_ACTIVE_LOW
#endif

/* Battery configuration */
#undef CONFIG_BATTERY
#ifdef CONFIG_PLATFORM_EC_BATTERY
#define CONFIG_BATTERY
#endif /* CONFIG_PLATFORM_EC_BATTERY */

#undef CONFIG_BATTERY_FUEL_GAUGE
#ifdef CONFIG_PLATFORM_EC_BATTERY_FUEL_GAUGE
#define CONFIG_BATTERY_FUEL_GAUGE
#endif /* CONFIG_PLATFORM_EC_BATTERY_FUEL_GAUGE */

#undef CONFIG_BATTERY_V1
#ifdef CONFIG_PLATFORM_EC_BATTERY_V1
#define CONFIG_BATTERY_V1
#endif

#undef CONFIG_BATTERY_V2
#ifdef CONFIG_PLATFORM_EC_BATTERY_V2
#define CONFIG_BATTERY_V2
#endif

#undef CONFIG_HOSTCMD_BATTERY_V2
#ifdef CONFIG_PLATFORM_EC_HOSTCMD_BATTERY_V2
#define CONFIG_HOSTCMD_BATTERY_V2
#endif

#undef CONFIG_BATTERY_COUNT
#define CONFIG_BATTERY_COUNT CONFIG_PLATFORM_EC_BATTERY_COUNT

#undef CONFIG_BATTERY_SMART
#ifdef CONFIG_PLATFORM_EC_BATTERY_SMART
#define CONFIG_BATTERY_SMART
#endif

#undef CONFIG_I2C_VIRTUAL_BATTERY
#undef I2C_PORT_VIRTUAL_BATTERY
#ifdef CONFIG_PLATFORM_EC_I2C_VIRTUAL_BATTERY
#define CONFIG_I2C_VIRTUAL_BATTERY
#define VIRTUAL_BATTERY_ADDR_FLAGS CONFIG_PLATFORM_EC_I2C_VIRTUAL_BATTERY_ADDR
#endif

#undef CONFIG_SMART_BATTERY_OPTIONAL_MFG_FUNC
#ifdef CONFIG_PLATFORM_EC_SMART_BATTERY_OPTIONAL_MFG_FUNC
#define CONFIG_SMART_BATTERY_OPTIONAL_MFG_FUNC
#endif

#undef CONFIG_I2C_PASSTHRU_RESTRICTED
#ifdef CONFIG_PLATFORM_EC_I2C_PASSTHRU_RESTRICTED
#define CONFIG_I2C_PASSTHRU_RESTRICTED
#endif

#undef CONFIG_CMD_I2C_SPEED
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_I2C_SPEED
#define CONFIG_CMD_I2C_SPEED
#endif

#undef CONFIG_HOSTCMD_I2C_CONTROL
#ifdef CONFIG_PLATFORM_EC_HOSTCMD_I2C_CONTROL
#define CONFIG_HOSTCMD_I2C_CONTROL
#endif

#undef CONFIG_BATTERY_PRESENT_CUSTOM
#ifdef CONFIG_PLATFORM_EC_BATTERY_PRESENT_CUSTOM
#define CONFIG_BATTERY_PRESENT_CUSTOM
#endif

#undef CONFIG_BATTERY_PRESENT_GPIO
#ifdef CONFIG_PLATFORM_EC_BATTERY_PRESENT_GPIO
/* This is always GPIO_BATT_PRES_ODL with Zephyr */
#define CONFIG_BATTERY_PRESENT_GPIO GPIO_BATT_PRES_ODL
#endif

#undef CONFIG_BATTERY_CRITICAL_SHUTDOWN_CUT_OFF
#ifdef CONFIG_PLATFORM_EC_BATTERY_CRITICAL_SHUTDOWN_CUT_OFF
#define CONFIG_BATTERY_CRITICAL_SHUTDOWN_CUT_OFF
#endif

#undef CONFIG_BATTERY_CHECK_CHARGE_TEMP_LIMITS
#ifdef CONFIG_PLATFORM_EC_BATTERY_CHECK_CHARGE_TEMP_LIMITS
#define CONFIG_BATTERY_CHECK_CHARGE_TEMP_LIMITS
#endif

#undef CONFIG_BATTERY_CUT_OFF
#ifdef CONFIG_PLATFORM_EC_BATTERY_CUT_OFF
#define CONFIG_BATTERY_CUT_OFF
#endif

#undef CONFIG_BATTERY_HW_PRESENT_CUSTOM
#ifdef CONFIG_PLATFORM_EC_BATTERY_HW_PRESENT_CUSTOM
#define CONFIG_BATTERY_HW_PRESENT_CUSTOM
#endif

#undef CONFIG_BATTERY_REVIVE_DISCONNECT
#ifdef CONFIG_PLATFORM_EC_BATTERY_REVIVE_DISCONNECT
#define CONFIG_BATTERY_REVIVE_DISCONNECT
#endif

#undef CONFIG_BATTERY_MEASURE_IMBALANCE
#ifdef CONFIG_PLATFORM_EC_BATTERY_MEASURE_IMBALANCE

#define CONFIG_BATTERY_MEASURE_IMBALANCE
#define CONFIG_BATTERY_MAX_IMBALANCE_MV \
	CONFIG_PLATFORM_EC_BATTERY_MAX_IMBALANCE_MV
#define CONFIG_CHARGER_MIN_BAT_PCT_IMBALANCED_POWER_ON \
	CONFIG_PLATFORM_EC_CHARGER_MIN_BAT_PCT_IMBALANCED_POWER_ON
#endif

#undef CONFIG_BATTERY_STBL_STAT
#ifdef CONFIG_PLATFORM_EC_BATTERY_STBL_STAT
#define CONFIG_BATTERY_STBL_STAT
#define CONFIG_BATT_ALARM_MASK1 CONFIG_PLATFORM_EC_BATT_ALARM_MASK1
#define CONFIG_BATT_ALARM_MASK2 CONFIG_PLATFORM_EC_BATT_ALARM_MASK2
#endif

#undef CONFIG_BATT_FULL_CHIPSET_OFF_INPUT_LIMIT_MV
#if defined(CONFIG_PLATFORM_EC_BATT_FULL_CHIPSET_OFF_INPUT_LIMIT_MV) && \
	(CONFIG_PLATFORM_EC_BATT_FULL_CHIPSET_OFF_INPUT_LIMIT_MV > 0)
#define CONFIG_BATT_FULL_CHIPSET_OFF_INPUT_LIMIT_MV \
	CONFIG_PLATFORM_EC_BATT_FULL_CHIPSET_OFF_INPUT_LIMIT_MV
#endif

#undef CONFIG_BOARD_RESET_AFTER_POWER_ON
#ifdef CONFIG_PLATFORM_EC_BOARD_RESET_AFTER_POWER_ON
#define CONFIG_BOARD_RESET_AFTER_POWER_ON
#endif

#undef CONFIG_CHARGER_ISL9241
#ifdef CONFIG_PLATFORM_EC_CHARGER_ISL9241
#define CONFIG_CHARGER_ISL9241
#endif

#undef CONFIG_CHARGER_RAA489110
#ifdef CONFIG_PLATFORM_EC_CHARGER_RAA489110
#define CONFIG_CHARGER_RAA489110
#endif

#undef CONFIG_OCPC
#ifdef CONFIG_PLATFORM_EC_OCPC
#define CONFIG_OCPC
#define CONFIG_OCPC_DEF_RBATT_MOHMS CONFIG_PLATFORM_EC_OCPC_DEF_RBATT_MOHMS
#endif

#undef CONFIG_OCPC_DEF_DRIVELIMIT_MILLIVOLTS
#ifdef CONFIG_PLATFORM_EC_OCPC_DEF_DRIVELIMIT_MILLIVOLTS
#define CONFIG_OCPC_DEF_DRIVELIMIT_MILLIVOLTS \
	CONFIG_PLATFORM_EC_OCPC_DEF_DRIVELIMIT_MILLIVOLTS
#endif

#undef CONFIG_CHARGER_SINGLE_CHIP
#ifdef CONFIG_PLATFORM_EC_CHARGER_SINGLE_CHIP
#define CONFIG_CHARGER_SINGLE_CHIP
#endif

#undef CONFIG_CHARGER_RUNTIME_CONFIG
#ifdef CONFIG_PLATFORM_EC_CHARGER_RUNTIME_CONFIG
#define CONFIG_CHARGER_RUNTIME_CONFIG
#endif

/*
 * Note - ISL9241 chargers for all channels are configured with the same
 * switching frequency set with the Kconfig config.
 */
#undef CONFIG_ISL9241_SWITCHING_FREQ
#if CONFIG_PLATFORM_EC_ISL9241_SWITCHING_FREQ != -1
#define CONFIG_ISL9241_SWITCHING_FREQ CONFIG_PLATFORM_EC_ISL9241_SWITCHING_FREQ
#endif

#undef CONFIG_CHARGER_ISL9237
#ifdef CONFIG_PLATFORM_EC_CHARGER_ISL9237
#define CONFIG_CHARGER_ISL9237
#endif

#undef CONFIG_CHARGER_ISL9238
#ifdef CONFIG_PLATFORM_EC_CHARGER_ISL9238
#define CONFIG_CHARGER_ISL9238
#endif

#undef CONFIG_CHARGER_ISL9238C
#ifdef CONFIG_PLATFORM_EC_CHARGER_ISL9238C
#define CONFIG_CHARGER_ISL9238C
#endif

#undef CONFIG_ISL9238C_DISABLE_CMOUT_LATCH
#ifdef CONFIG_PLATFORM_EC_ISL9238C_DISABLE_CMOUT_LATCH
#define CONFIG_ISL9238C_DISABLE_CMOUT_LATCH
#endif

#undef CONFIG_ISL9238C_ENABLE_BUCK_MODE
#ifdef CONFIG_PLATFORM_EC_ISL9238C_ENABLE_BUCK_MODE
#define CONFIG_ISL9238C_ENABLE_BUCK_MODE
#endif

#undef CONFIG_ISL9238C_BUCK_PHASE_VOLTAGE
#ifdef CONFIG_PLATFORM_EC_ISL9238C_BUCK_PHASE_VOLTAGE
#define CONFIG_ISL9238C_BUCK_PHASE_VOLTAGE \
	CONFIG_PLATFORM_EC_ISL9238C_BUCK_PHASE_VOLTAGE
#endif

#undef CONFIG_PRECHARGE_DELAY_MS
#ifdef CONFIG_PLATFORM_EC_PRECHARGE_DELAY_MS
#define CONFIG_PRECHARGE_DELAY_MS CONFIG_PLATFORM_EC_PRECHARGE_DELAY_MS
#endif

#undef CONFIG_AC_PROCHOT_CURRENT_MA
#ifdef CONFIG_PLATFORM_EC_AC_PROCHOT_CURRENT_MA
#define CONFIG_AC_PROCHOT_CURRENT_MA CONFIG_PLATFORM_EC_AC_PROCHOT_CURRENT_MA
#endif

#undef CONFIG_DC_PROCHOT_CURRENT_MA
#ifdef CONFIG_PLATFORM_EC_DC_PROCHOT_CURRENT_MA
#define CONFIG_DC_PROCHOT_CURRENT_MA CONFIG_PLATFORM_EC_DC_PROCHOT_CURRENT_MA
#endif

#undef CONFIG_CHARGER_DUMP_PROCHOT
#ifdef CONFIG_PLATFORM_EC_CHARGER_DUMP_PROCHOT
#define CONFIG_CHARGER_DUMP_PROCHOT
#endif

#undef CONFIG_CHARGER_RAA489000
#ifdef CONFIG_PLATFORM_EC_CHARGER_RAA489000
#define CONFIG_CHARGER_RAA489000
#endif

#undef CONFIG_CHARGER_SM5803
#ifdef CONFIG_PLATFORM_EC_CHARGER_SM5803
#define CONFIG_CHARGER_SM5803
#endif

#undef CONFIG_CHARGER_SM5803_PROCHOT_DURATION
#ifdef CONFIG_PLATFORM_EC_CHARGER_SM5803_PROCHOT_DURATION
#define CONFIG_CHARGER_SM5803_PROCHOT_DURATION \
	CONFIG_PLATFORM_EC_CHARGER_SM5803_PROCHOT_DURATION
#endif

#undef CONFIG_CHARGER_SM5803_VBUS_MON_SEL
#ifdef CONFIG_PLATFORM_EC_CHARGER_SM5803_VBUS_MON_SEL
#define CONFIG_CHARGER_SM5803_VBUS_MON_SEL \
	CONFIG_PLATFORM_EC_CHARGER_SM5803_VBUS_MON_SEL
#endif

#undef CONFIG_CHARGER_SM5803_VSYS_MON_SEL
#ifdef CONFIG_PLATFORM_EC_CHARGER_SM5803_VSYS_MON_SEL
#define CONFIG_CHARGER_SM5803_VSYS_MON_SEL \
	CONFIG_PLATFORM_EC_CHARGER_SM5803_VSYS_MON_SEL
#endif

#undef CONFIG_CHARGER_SM5803_IBAT_PHOT_SEL
#ifdef CONFIG_PLATFORM_EC_CHARGER_SM5803_IBAT_PHOT_SEL
#define CONFIG_CHARGER_SM5803_IBAT_PHOT_SEL \
	CONFIG_PLATFORM_EC_CHARGER_SM5803_IBAT_PHOT_SEL
#endif

#undef CONFIG_CHARGER_MAINTAIN_VBAT
#ifdef CONFIG_PLATFORM_EC_CHARGER_MAINTAIN_VBAT
#define CONFIG_CHARGER_MAINTAIN_VBAT
#endif

#undef CONFIG_CHARGER_TRICKLE
#ifdef CONFIG_PLATFORM_EC_CHARGER_TRICKLE
#define CONFIG_TRICKLE_CHARGING
#endif

#ifdef CONFIG_PLATFORM_EC_RAA489000_TRICKLE_CHARGE_CURRENT
#undef CONFIG_RAA489000_TRICKLE_CHARGE_CURRENT
#define CONFIG_RAA489000_TRICKLE_CHARGE_CURRENT \
	CONFIG_PLATFORM_EC_RAA489000_TRICKLE_CHARGE_CURRENT
#endif

#undef CONFIG_CHARGER_BYPASS_MODE
#ifdef CONFIG_PLATFORM_EC_CHARGER_BYPASS_MODE
#define CONFIG_CHARGER_BYPASS_MODE
#endif

#undef CONFIG_CHARGER_NARROW_VDC
#ifdef CONFIG_PLATFORM_EC_CHARGER_NARROW_VDC
#define CONFIG_CHARGER_NARROW_VDC
#endif

#undef CONFIG_CHARGER_OTG
#ifdef CONFIG_PLATFORM_EC_CHARGER_OTG
#define CONFIG_CHARGER_OTG
#endif

#undef CONFIG_CHIPSET_RESET_HOOK
#ifdef CONFIG_PLATFORM_EC_CHIPSET_RESET_HOOK
#define CONFIG_CHIPSET_RESET_HOOK
#endif

#undef CONFIG_CHIPSET_RESUME_INIT_HOOK
#ifdef CONFIG_PLATFORM_EC_CHIPSET_RESUME_INIT_HOOK
#define CONFIG_CHIPSET_RESUME_INIT_HOOK
#endif

#undef CONFIG_CHIP_INIT_ROM_REGION
#ifdef CONFIG_PLATFORM_EC_CHIP_INIT_ROM_REGION
#define CONFIG_CHIP_INIT_ROM_REGION
#endif

#undef CONFIG_EXTPOWER
#ifdef CONFIG_PLATFORM_EC_EXTPOWER
#define CONFIG_EXTPOWER
#endif

#undef CONFIG_EXTPOWER_GPIO
#ifdef CONFIG_PLATFORM_EC_EXTPOWER_GPIO
#define CONFIG_EXTPOWER_GPIO
#endif

/* Bringup configuration */
#undef CONFIG_BRINGUP
#ifdef CONFIG_PLATFORM_EC_BRINGUP
#define CONFIG_BRINGUP
#endif

#undef CONFIG_EMULATED_SYSRQ
#ifdef CONFIG_PLATFORM_EC_EMULATED_SYSRQ
#define CONFIG_EMULATED_SYSRQ
#endif

/* Host interface selection */
#undef CONFIG_HOST_INTERFACE_ESPI
#ifdef CONFIG_PLATFORM_EC_HOST_INTERFACE_ESPI
#define CONFIG_HOST_INTERFACE_ESPI
#endif

#undef CONFIG_HOST_INTERFACE_HECI
#ifdef CONFIG_PLATFORM_EC_HOST_INTERFACE_HECI
#define CONFIG_HOST_INTERFACE_HECI
#endif

#undef CONFIG_HOST_INTERFACE_LPC
#ifdef CONFIG_PLATFORM_EC_HOST_INTERFACE_LPC
#define CONFIG_HOST_INTERFACE_LPC
#endif

#undef CONFIG_HOST_INTERFACE_SHI
#ifdef CONFIG_PLATFORM_EC_HOST_INTERFACE_SHI
#define CONFIG_HOST_INTERFACE_SHI
#endif

#undef CONFIG_HOST_INTERFACE_USB
#ifdef CONFIG_PLATFORM_EC_HOST_INTERFACE_USB
#define CONFIG_HOST_INTERFACE_USB
#endif

/* eSPI signals */
#undef CONFIG_HOST_INTERFACE_ESPI_VW_SLP_S3
#ifdef CONFIG_PLATFORM_EC_HOST_INTERFACE_ESPI_VW_SLP_S3
#define CONFIG_HOST_INTERFACE_ESPI_VW_SLP_S3
#endif

#undef CONFIG_HOST_INTERFACE_ESPI_VW_SLP_S4
#ifdef CONFIG_PLATFORM_EC_HOST_INTERFACE_ESPI_VW_SLP_S4
#define CONFIG_HOST_INTERFACE_ESPI_VW_SLP_S4
#endif

#undef CONFIG_HOST_INTERFACE_ESPI_VW_SLP_S5
#ifdef CONFIG_PLATFORM_EC_HOST_INTERFACE_ESPI_VW_SLP_S5
#define CONFIG_HOST_INTERFACE_ESPI_VW_SLP_S5
#endif

#undef CONFIG_HOST_INTERFACE_ESPI_RESET_SLP_SX_VW_ON_ESPI_RST
#ifdef CONFIG_PLATFORM_EC_HOST_INTERFACE_ESPI_RESET_SLP_SX_VW_ON_ESPI_RST
#define CONFIG_HOST_INTERFACE_ESPI_RESET_SLP_SX_VW_ON_ESPI_RST
#endif

#undef CONFIG_HOST_INTERFACE_ESPI_DEFAULT_VW_WIDTH_US
#ifdef CONFIG_PLATFORM_EC_DEFAULT_SCI_WIDTH_US
#define CONFIG_HOST_INTERFACE_ESPI_DEFAULT_VW_WIDTH_US \
	CONFIG_PLATFORM_EC_DEFAULT_SCI_WIDTH_US
#endif

#if DT_HAS_CHOSEN(zephyr_flash)
#define CONFIG_PROGRAM_MEMORY_BASE \
	_CONCAT(DT_REG_ADDR(DT_CHOSEN(zephyr_flash)), U)
#else
#error "A zephyr,flash device must be chosen in the device tree"
#endif

#if DT_HAS_CHOSEN(zephyr_sram)
#define CONFIG_RAM_BASE DT_REG_ADDR(DT_CHOSEN(zephyr_sram))
#define CONFIG_DATA_RAM_SIZE DT_REG_SIZE(DT_CHOSEN(zephyr_sram))
#elif defined(CONFIG_ARCH_POSIX)
/* The jump data goes at the end of data ram, so for posix, the end of ram is
 * wherever the jump data ended up.
 */
extern char mock_jump_data[CONFIG_PLATFORM_EC_PRESERVED_END_OF_RAM_SIZE];
#define CONFIG_RAM_BASE 0x0
/* clang-format off */
#define CONFIG_DATA_RAM_SIZE            \
	(((uintptr_t)&mock_jump_data) + \
	 CONFIG_PLATFORM_EC_PRESERVED_END_OF_RAM_SIZE)
/* clang-format on */
#else
#error "A zephyr,sram device must be chosen in the device tree"
#endif

#define CONFIG_RAM_SIZE CONFIG_DATA_RAM_SIZE

#undef CONFIG_PRESERVED_END_OF_RAM_SIZE
#ifdef CONFIG_PLATFORM_EC_PRESERVED_END_OF_RAM_SIZE
#define CONFIG_PRESERVED_END_OF_RAM_SIZE \
	CONFIG_PLATFORM_EC_PRESERVED_END_OF_RAM_SIZE
#endif

#define CONFIG_RO_MEM_OFF CONFIG_CROS_EC_RO_MEM_OFF
#define CONFIG_RO_MEM_SIZE CONFIG_CROS_EC_RO_MEM_SIZE
#define CONFIG_RW_MEM_OFF CONFIG_CROS_EC_RW_MEM_OFF
#define CONFIG_RW_MEM_SIZE CONFIG_CROS_EC_RW_MEM_SIZE

#define CONFIG_WP_STORAGE_OFF CONFIG_EC_PROTECTED_STORAGE_OFF
#define CONFIG_WP_STORAGE_SIZE CONFIG_EC_PROTECTED_STORAGE_SIZE
#if defined(CONFIG_PLATFORM_EC_FLASH_PSTATE)
#define CONFIG_RO_SIZE (CONFIG_CROS_EC_RO_SIZE - CONFIG_FW_PSTATE_SIZE)
#else
#define CONFIG_RO_SIZE CONFIG_CROS_EC_RO_SIZE
#endif
#define CONFIG_RW_SIZE CONFIG_CROS_EC_RW_SIZE

/*
 * ROM resident area in flash used to store data objects that are not copied
 * into code RAM. Enable using the CONFIG_CHIP_INIT_ROM_REGION option.
 */
#define CONFIG_RO_ROM_RESIDENT_MEM_OFF CONFIG_RO_SIZE
#define CONFIG_RO_ROM_RESIDENT_SIZE \
	(CONFIG_EC_PROTECTED_STORAGE_SIZE - CONFIG_RO_SIZE)

/*
 * RW firmware in program memory - Identical to RO, only one image loaded at
 * a time.
 */
#define CONFIG_RW_ROM_RESIDENT_MEM_OFF CONFIG_RW_SIZE
#define CONFIG_RW_ROM_RESIDENT_SIZE \
	(CONFIG_EC_WRITABLE_STORAGE_SIZE - CONFIG_RW_SIZE)

/* Flash settings */
#undef CONFIG_EXTERNAL_STORAGE
#undef CONFIG_INTERNAL_STORAGE
#undef CONFIG_MAPPED_STORAGE
#undef CONFIG_FLASH_PSTATE
#undef CONFIG_FLASH_PSTATE_BANK
#undef CONFIG_FLASH_PSTATE_LOCKED
#ifdef CONFIG_PLATFORM_EC_FLASH_CROS

#ifdef CONFIG_BOARD_NATIVE_POSIX
#include "flash_chip_native_posix.h"
#else
#include "flash_chip.h"
#endif

#define CONFIG_FLASH_CROS

/* Internal, don't use outside this header */
#define _BINMAN_RO_PATH DT_PATH(binman, wp_ro)
#define _BINMAN_RW_PATH DT_PATH(binman, ec_rw)

#define CONFIG_EC_PROTECTED_STORAGE_OFF DT_PROP(_BINMAN_RO_PATH, offset)
#define CONFIG_EC_PROTECTED_STORAGE_SIZE DT_PROP(_BINMAN_RO_PATH, size)
#define CONFIG_EC_WRITABLE_STORAGE_OFF DT_PROP(_BINMAN_RW_PATH, offset)
#define CONFIG_EC_WRITABLE_STORAGE_SIZE DT_PROP(_BINMAN_RW_PATH, size)

#undef CONFIG_EXTERNAL_STORAGE
#ifdef CONFIG_PLATFORM_EC_EXTERNAL_STORAGE
#define CONFIG_EXTERNAL_STORAGE
#endif

#undef CONFIG_INTERNAL_STORAGE
#ifdef CONFIG_PLATFORM_EC_INTERNAL_STORAGE
#define CONFIG_INTERNAL_STORAGE
#endif

#undef CONFIG_MAPPED_STORAGE
#ifdef CONFIG_PLATFORM_EC_MAPPED_STORAGE
#define CONFIG_MAPPED_STORAGE
#endif

#undef CONFIG_FLASH_PSTATE
#ifdef CONFIG_PLATFORM_EC_FLASH_PSTATE
#define CONFIG_FLASH_PSTATE
#endif

#undef CONFIG_FLASH_PSTATE_BANK
#ifdef CONFIG_PLATFORM_EC_FLASH_PSTATE_BANK
#define CONFIG_FLASH_PSTATE_BANK
#endif

#undef CONFIG_FLASH_PSTATE_LOCKED
#ifdef CONFIG_PLATFORM_EC_FLASH_PSTATE_LOCKED
#define CONFIG_FLASH_PSTATE_LOCKED
#endif

#undef CONFIG_CMD_FLASH
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_FLASH
#define CONFIG_CMD_FLASH
#endif

#undef CONFIG_CMD_FLASHINFO
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_FLASHINFO
#define CONFIG_CMD_FLASHINFO
#endif

#undef CONFIG_CMD_FLASH_WP
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_FLASH_WP
#define CONFIG_CMD_FLASH_WP
#endif

#undef CONFIG_FLASH_MULTIPLE_REGION
#ifdef CONFIG_PLATFORM_EC_USE_ZEPHYR_FLASH_PAGE_LAYOUT
#define CONFIG_FLASH_MULTIPLE_REGION
#endif

#endif /* CONFIG_PLATFORM_EC_FLASH_CROS */

#undef CONFIG_MAPPED_STORAGE_BASE
#ifdef CONFIG_PLATFORM_EC_MAPPED_STORAGE_BASE
#define CONFIG_MAPPED_STORAGE_BASE CONFIG_PLATFORM_EC_MAPPED_STORAGE_BASE
#endif

#undef CONFIG_FLASH_SIZE_BYTES
#ifdef CONFIG_PLATFORM_EC_FLASH_SIZE_BYTES
#define CONFIG_FLASH_SIZE_BYTES CONFIG_PLATFORM_EC_FLASH_SIZE_BYTES
#endif /* CONFIG_PLATFORM_EC_FLASH_SIZE_BYTES */

#undef CONFIG_ADC_CHANNELS_RUNTIME_CONFIG
#ifdef CONFIG_PLATFORM_EC_ADC_CHANNELS_RUNTIME_CONFIG
#define CONFIG_ADC_CHANNELS_RUNTIME_CONFIG
#endif

#undef CONFIG_CMD_ADC
#ifdef CONFIG_PLATFORM_EC_ADC_CMD
#define CONFIG_CMD_ADC
#endif

#undef CONFIG_TEMP_SENSOR
#ifdef CONFIG_PLATFORM_EC_TEMP_SENSOR
#define CONFIG_TEMP_SENSOR
#endif

#undef CONFIG_TEMP_SENSOR_POWER
#ifdef CONFIG_PLATFORM_EC_TEMP_SENSOR_POWER
#define CONFIG_TEMP_SENSOR_POWER
#endif

#undef CONFIG_THERMISTOR
#ifdef CONFIG_PLATFORM_EC_THERMISTOR
#define CONFIG_THERMISTOR
#endif

#undef CONFIG_TEMP_SENSOR_PCT2075
#ifdef CONFIG_PLATFORM_EC_TEMP_SENSOR_PCT2075
#define CONFIG_TEMP_SENSOR_PCT2075
#endif

#undef CONFIG_TEMP_SENSOR_SB_TSI
#ifdef CONFIG_PLATFORM_EC_TEMP_SENSOR_SB_TSI
#define CONFIG_TEMP_SENSOR_SB_TSI
#endif

#undef CONFIG_TEMP_SENSOR_TMP112
#ifdef CONFIG_PLATFORM_EC_TEMP_SENSOR_TMP112
#define CONFIG_TEMP_SENSOR_TMP112
#endif

#undef CONFIG_TEMP_SENSOR_F75303
#ifdef CONFIG_PLATFORM_EC_TEMP_SENSOR_F75303
#define CONFIG_TEMP_SENSOR_F75303
#endif

#undef CONFIG_FANS
#ifdef CONFIG_PLATFORM_EC_NUM_FANS
#define CONFIG_FANS CONFIG_PLATFORM_EC_NUM_FANS
#endif

#undef CONFIG_FAN_DYNAMIC_CONFIG
#ifdef CONFIG_PLATFORM_EC_FAN_DYNAMIC_CONFIG
#define CONFIG_FAN_DYNAMIC_CONFIG
#endif

#undef CONFIG_FAN_BYPASS_SLOW_RESPONSE
#ifdef PLATFORM_EC_FAN_BYPASS_SLOW_RESPONSE
#define CONFIG_FAN_BYPASS_SLOW_RESPONSE
#endif

#undef CONFIG_CUSTOM_FAN_CONTROL
#ifdef CONFIG_PLATFORM_EC_CUSTOM_FAN_CONTROL
#define CONFIG_CUSTOM_FAN_CONTROL
#endif

#undef CONFIG_I2C_CONTROLLER
#ifdef CONFIG_PLATFORM_EC_I2C
/* Also see shim/include/i2c/i2c.h which defines the ports enum */
#define CONFIG_I2C_CONTROLLER
#endif

#undef CONFIG_I2C_DEBUG
#ifdef CONFIG_PLATFORM_EC_I2C_DEBUG
#define CONFIG_I2C_DEBUG
#endif

#undef CONFIG_I2C_DEBUG_PASSTHRU
#ifdef CONFIG_PLATFORM_EC_I2C_DEBUG_PASSTHRU
#define CONFIG_I2C_DEBUG_PASSTHRU
#endif

#undef CONFIG_SMBUS_PEC
#ifdef CONFIG_PLATFORM_EC_SMBUS_PEC
#define CONFIG_SMBUS_PEC
#endif

#undef CONFIG_I2C_NACK_RETRY_COUNT
#ifdef CONFIG_PLATFORM_EC_I2C_NACK_RETRY_COUNT
#define CONFIG_I2C_NACK_RETRY_COUNT CONFIG_PLATFORM_EC_I2C_NACK_RETRY_COUNT
#endif

#undef CONFIG_KEYBOARD_PROTOCOL_8042
#ifdef CONFIG_PLATFORM_EC_KEYBOARD_PROTOCOL_8042
#define CONFIG_KEYBOARD_PROTOCOL_8042
#endif /* CONFIG_PLATFORM_EC_KEYBOARD_PROTOCOL_8042 */

#undef CONFIG_KEYBOARD_PROTOCOL_MKBP
#ifdef CONFIG_PLATFORM_EC_KEYBOARD_PROTOCOL_MKBP
#define CONFIG_KEYBOARD_PROTOCOL_MKBP
#endif

#undef CONFIG_KEYBOARD_DEBUG
#ifdef CONFIG_PLATFORM_EC_KEYBOARD_DEBUG
#define CONFIG_KEYBOARD_DEBUG
#endif

#undef CONFIG_KEYBOARD_DISCRETE
#ifdef CONFIG_PLATFORM_EC_KEYBOARD_DISCRETE
#define CONFIG_KEYBOARD_DISCRETE
#define KB_DISCRETE_I2C_ADDR_FLAGS DT_REG_ADDR(DT_NODELABEL(kb_discrete))
#endif

#undef CONFIG_MKBP_INPUT_DEVICES
#ifdef CONFIG_PLATFORM_EC_MKBP_INPUT_DEVICES
#define CONFIG_MKBP_INPUT_DEVICES
#endif

#undef CONFIG_MKBP_EVENT_WAKEUP_MASK
#if defined(CONFIG_PLATFORM_EC_MKBP_EVENT_WAKEUP_MASK) && \
	CONFIG_PLATFORM_EC_MKBP_EVENT_WAKEUP_MASK
#define CONFIG_MKBP_EVENT_WAKEUP_MASK                                          \
	DT_PROP(DT_COMPAT_GET_ANY_STATUS_OKAY(cros_ec_mkbp_event_wakeup_mask), \
		wakeup_mask)
#endif

#undef CONFIG_MKBP_HOST_EVENT_WAKEUP_MASK
#if defined(CONFIG_PLATFORM_EC_MKBP_HOST_EVENT_WAKEUP_MASK) && \
	CONFIG_PLATFORM_EC_MKBP_HOST_EVENT_WAKEUP_MASK
#define CONFIG_MKBP_HOST_EVENT_WAKEUP_MASK                    \
	DT_PROP(DT_COMPAT_GET_ANY_STATUS_OKAY(                \
			cros_ec_mkbp_host_event_wakeup_mask), \
		wakeup_mask)
#endif

#undef CONFIG_CMD_KEYBOARD
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_KEYBOARD
#define CONFIG_CMD_KEYBOARD
#endif

#undef CONFIG_KEYBOARD_COL2_INVERTED
#ifdef CONFIG_PLATFORM_EC_KEYBOARD_COL2_INVERTED
#define CONFIG_KEYBOARD_COL2_INVERTED
#endif /* CONFIG_PLATFORM_EC_KEYBOARD_COL2_INVERTED */

#undef CONFIG_KEYBOARD_REFRESH_ROW3
#ifdef CONFIG_PLATFORM_EC_KEYBOARD_REFRESH_ROW3
#define CONFIG_KEYBOARD_REFRESH_ROW3
#endif /* CONFIG_PLATFORM_EC_KEYBOARD_REFRESH_ROW3 */

#undef CONFIG_KEYBOARD_FACTORY_TEST
#ifdef CONFIG_PLATFORM_EC_KEYBOARD_FACTORY_TEST
#define CONFIG_KEYBOARD_FACTORY_TEST
#endif

#undef CONFIG_KEYBOARD_KEYPAD
#ifdef CONFIG_PLATFORM_EC_KEYBOARD_KEYPAD
#define CONFIG_KEYBOARD_KEYPAD
#endif

#undef CONFIG_KEYBOARD_CUSTOMIZATION
#ifdef CONFIG_PLATFORM_EC_KEYBOARD_CUSTOMIZATION
#define CONFIG_KEYBOARD_CUSTOMIZATION
#endif

#undef CONFIG_KEYBOARD_PWRBTN_ASSERTS_KSI2
#ifdef CONFIG_PLATFORM_EC_KEYBOARD_PWRBTN_ASSERTS_KSI2
#define CONFIG_KEYBOARD_PWRBTN_ASSERTS_KSI2
#endif

#undef CONFIG_KEYBOARD_PWRBTN_ASSERTS_KSI3
#ifdef CONFIG_PLATFORM_EC_KEYBOARD_PWRBTN_ASSERTS_KSI3
#define CONFIG_KEYBOARD_PWRBTN_ASSERTS_KSI3
#endif

#undef CONFIG_VOLUME_BUTTONS
#ifdef CONFIG_PLATFORM_EC_VOLUME_BUTTONS
#define CONFIG_VOLUME_BUTTONS
#endif

#undef CONFIG_BUTTONS_RUNTIME_CONFIG
#ifdef CONFIG_PLATFORM_EC_BUTTONS_RUNTIME_CONFIG
#define CONFIG_BUTTONS_RUNTIME_CONFIG
#endif

#undef CONFIG_CMD_BUTTON
#ifdef CONFIG_PLATFORM_EC_CMD_BUTTON
#define CONFIG_CMD_BUTTON
#endif

#undef CONFIG_BUTTON_TRIGGERED_RECOVERY
#ifdef CONFIG_PLATFORM_EC_BUTTON_TRIGGERED_RECOVERY
#define CONFIG_BUTTON_TRIGGERED_RECOVERY
#endif

#undef CONFIG_DEDICATED_RECOVERY_BUTTON
#ifdef CONFIG_PLATFORM_EC_DEDICATED_RECOVERY_BUTTON
#define CONFIG_DEDICATED_RECOVERY_BUTTON
#endif

#undef CONFIG_DEDICATED_RECOVERY_BUTTON_FLAGS
#ifdef CONFIG_PLATFORM_EC_DEDICATED_RECOVERY_BUTTON_ACTIVE_HIGH
#define CONFIG_DEDICATED_RECOVERY_BUTTON_FLAGS BUTTON_FLAG_ACTIVE_HIGH
#endif

#undef CONFIG_DEDICATED_RECOVERY_BUTTON_2
#ifdef CONFIG_PLATFORM_EC_DEDICATED_RECOVERY_BUTTON_2
#define CONFIG_DEDICATED_RECOVERY_BUTTON_2
#endif

#undef CONFIG_DEDICATED_RECOVERY_BUTTON_2_FLAGS
#ifdef CONFIG_PLATFORM_EC_DEDICATED_RECOVERY_BUTTON_2_ACTIVE_HIGH
#define CONFIG_DEDICATED_RECOVERY_BUTTON_2_FLAGS BUTTON_FLAG_ACTIVE_HIGH
#endif

#undef CONFIG_PSE_LTC4291
#ifdef PLATFORM_EC_PSE_LTC4291
#define CONFIG_PSE_LTC4291
#endif

#undef CONFIG_KEYBOARD_BACKLIGHT
#ifdef CONFIG_PLATFORM_KEYBOARD_BACKLIGHT
#define CONFIG_KEYBOARD_BACKLIGHT
#endif

#undef CONFIG_PWM_KBLIGHT
#ifdef CONFIG_PLATFORM_EC_PWM_KBLIGHT
#define CONFIG_PWM_KBLIGHT
#endif

#undef CONFIG_KBLIGHT_ENABLE_PIN
#ifdef CONFIG_PLATFORM_EC_KBLIGHT_ENABLE_PIN
#define CONFIG_KBLIGHT_ENABLE_PIN
#endif

#undef CONFIG_KBLIGHT_HOOK_INIT
#ifdef CONFIG_PLATFORM_EC_KBLIGHT_HOOK_INIT
#define CONFIG_KBLIGHT_HOOK_INIT
#endif

#undef CONFIG_KEYBOARD_STRICT_DEBOUNCE
#ifdef CONFIG_PLATFORM_EC_KEYBOARD_STRICT_DEBOUNCE
#define CONFIG_KEYBOARD_STRICT_DEBOUNCE
#endif

#undef CONFIG_LED_COMMON
#ifdef CONFIG_PLATFORM_EC_LED_COMMON
#define CONFIG_LED_COMMON
#endif

#undef CONFIG_LED_PWM
#ifdef CONFIG_PLATFORM_EC_LED_PWM
#define CONFIG_LED_PWM
#endif

#undef CONFIG_LED_PWM_TASK_DISABLED
#ifdef CONFIG_PLATFORM_EC_LED_PWM_TASK_DISABLED
#define CONFIG_LED_PWM_TASK_DISABLED
#endif

#undef CONFIG_LED_PWM_COUNT
#if DT_HAS_COMPAT_STATUS_OKAY(cros_ec_pwm_leds)
#define CONFIG_LED_PWM_COUNT DT_PROP_LEN(DT_INST(0, cros_ec_pwm_leds), leds)
#endif

#ifdef CONFIG_PLATFORM_EC_LED_PWM_CHARGE_COLOR
#undef CONFIG_LED_PWM_CHARGE_COLOR
#define CONFIG_LED_PWM_CHARGE_COLOR CONFIG_PLATFORM_EC_LED_PWM_CHARGE_COLOR
#endif

#ifdef CONFIG_PLATFORM_EC_LED_PWM_NEAR_FULL_COLOR
#undef CONFIG_LED_PWM_NEAR_FULL_COLOR
#define CONFIG_LED_PWM_NEAR_FULL_COLOR \
	CONFIG_PLATFORM_EC_LED_PWM_NEAR_FULL_COLOR
#endif

#ifdef CONFIG_PLATFORM_EC_LED_PWM_CHARGE_ERROR_COLOR
#undef CONFIG_LED_PWM_CHARGE_ERROR_COLOR
#define CONFIG_LED_PWM_CHARGE_ERROR_COLOR \
	CONFIG_PLATFORM_EC_LED_PWM_CHARGE_ERROR_COLOR
#endif

#ifdef CONFIG_PLATFORM_EC_LED_PWM_SOC_ON_COLOR
#undef CONFIG_LED_PWM_SOC_ON_COLOR
#define CONFIG_LED_PWM_SOC_ON_COLOR CONFIG_PLATFORM_EC_LED_PWM_SOC_ON_COLOR
#endif

#ifdef CONFIG_PLATFORM_EC_LED_PWM_SOC_SUSPEND_COLOR
#undef CONFIG_LED_PWM_SOC_SUSPEND_COLOR
#define CONFIG_LED_PWM_SOC_SUSPEND_COLOR \
	CONFIG_PLATFORM_EC_LED_PWM_SOC_SUSPEND_COLOR
#endif

#ifdef CONFIG_PLATFORM_EC_LED_PWM_LOW_BATT_COLOR
#undef CONFIG_LED_PWM_LOW_BATT_COLOR
#define CONFIG_LED_PWM_LOW_BATT_COLOR CONFIG_PLATFORM_EC_LED_PWM_LOW_BATT_COLOR
#endif

#ifdef CONFIG_PLATFORM_EC_LED_PWM_OFF_IN_SUSPEND
#undef CONFIG_LED_PWM_OFF_IN_SUSPEND
#define CONFIG_LED_PWM_OFF_IN_SUSPEND CONFIG_PLATFORM_EC_LED_PWM_OFF_IN_SUSPEND
#endif

#undef CONFIG_CMD_LEDTEST
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_LEDTEST
#define CONFIG_CMD_LEDTEST
#endif

#undef CONFIG_LED_ONOFF_STATES
#ifdef CONFIG_PLATFORM_EC_LED_ONOFF_STATES
#define CONFIG_LED_ONOFF_STATES
#endif

#undef CONFIG_LED_ONOFF_STATES_BAT_LOW
#ifdef CONFIG_PLATFORM_EC_LED_ONOFF_STATES_BAT_LOW
#define CONFIG_LED_ONOFF_STATES_BAT_LOW \
	CONFIG_PLATFORM_EC_LED_ONOFF_STATES_BAT_LOW
#endif

#undef CONFIG_PWM_DISPLIGHT
#ifdef CONFIG_PLATFORM_EC_PWM_DISPLIGHT
#define CONFIG_PWM_DISPLIGHT
#endif

#undef CONFIG_CPU_PROCHOT_ACTIVE_LOW
#ifdef CONFIG_PLATFORM_EC_POWERSEQ_CPU_PROCHOT_ACTIVE_LOW
#define CONFIG_CPU_PROCHOT_ACTIVE_LOW
#endif

#undef CONFIG_CPU_PROCHOT_GATE_ON_C10
#ifdef CONFIG_PLATFORM_EC_POWERSEQ_CPU_PROCHOT_GATE_ON_C10
#define CONFIG_CPU_PROCHOT_GATE_ON_C10
#endif

#undef CONFIG_POWER_TRACK_HOST_SLEEP_STATE
#if defined(CONFIG_PLATFORM_EC_POWERSEQ_HOST_SLEEP) || \
	defined(CONFIG_AP_PWRSEQ_HOST_SLEEP)
#define CONFIG_POWER_TRACK_HOST_SLEEP_STATE
#endif

#undef CONFIG_POWER_SLEEP_FAILURE_DETECTION
#ifdef CONFIG_PLATFORM_EC_POWER_SLEEP_FAILURE_DETECTION
#define CONFIG_POWER_SLEEP_FAILURE_DETECTION
#endif

#undef CONFIG_POWERSEQ_S0IX_COUNTER
#ifdef CONFIG_PLATFORM_EC_POWERSEQ_S0IX_COUNTER
#define CONFIG_POWERSEQ_S0IX_COUNTER
#endif

#undef CONFIG_HOSTCMD_AP_RESET
#ifdef CONFIG_PLATFORM_EC_HOSTCMD_AP_RESET
#define CONFIG_HOSTCMD_AP_RESET
#endif

#undef CONFIG_CHIPSET_X86_RSMRST_DELAY
#ifdef CONFIG_PLATFORM_EC_POWERSEQ_RSMRST_DELAY
#define CONFIG_CHIPSET_X86_RSMRST_DELAY
#endif

#undef CONFIG_CHIPSET_X86_RSMRST_AFTER_S5
#ifdef CONFIG_PLATFORM_EC_POWERSEQ_RSMRST_AFTER_S5
#define CONFIG_CHIPSET_X86_RSMRST_AFTER_S5
#endif

#undef CONFIG_CHIPSET_SLP_S3_L_OVERRIDE
#ifdef CONFIG_PLATFORM_EC_POWERSEQ_SLP_S3_L_OVERRIDE
#define CONFIG_CHIPSET_SLP_S3_L_OVERRIDE
#endif

#undef CONFIG_CHIPSET_PP3300_RAIL_FIRST
#ifdef CONFIG_PLATFORM_EC_POWERSEQ_PP3300_RAIL_FIRST
#define CONFIG_CHIPSET_PP3300_RAIL_FIRST
#endif

#ifdef CONFIG_PLATFORM_EC_POWERSEQ_RTC_RESET
#define CONFIG_BOARD_HAS_RTC_RESET
#define CONFIG_S5_EXIT_WAIT CONFIG_PLATFORM_EC_S5_EXIT_WAIT
#endif

#undef CONFIG_POWER_PP5000_CONTROL
#ifdef CONFIG_PLATFORM_EC_POWERSEQ_PP5000_CONTROL
#define CONFIG_POWER_PP5000_CONTROL
#endif

#undef CONFIG_POWER_S0IX
#if defined(CONFIG_PLATFORM_EC_POWERSEQ_S0IX) || defined(CONFIG_AP_PWRSEQ_S0IX)
#define CONFIG_POWER_S0IX
#endif

#undef CONFIG_POWER_S4_RESIDENCY
#ifdef CONFIG_PLATFORM_EC_POWERSEQ_S4
#define CONFIG_POWER_S4_RESIDENCY
#endif

#undef CONFIG_POWER_BUTTON_X86
#ifdef CONFIG_PLATFORM_EC_POWERSEQ_INTEL
#define CONFIG_POWER_BUTTON_X86
#endif

#undef CONFIG_POWER_BUTTON_IGNORE_LID
#ifdef CONFIG_PLATFORM_EC_POWER_BUTTON_IGNORE_LID
#define CONFIG_POWER_BUTTON_IGNORE_LID
#endif

#undef CONFIG_POWER_BUTTON_TO_PCH_CUSTOM
#ifdef CONFIG_PLATFORM_EC_POWER_BUTTON_TO_PCH_CUSTOM
#define CONFIG_POWER_BUTTON_TO_PCH_CUSTOM
#endif

#undef CONFIG_POWER_BUTTON_INIT_TIMEOUT
#ifdef CONFIG_PLATFORM_EC_POWER_BUTTON_INIT_TIMEOUT
#define CONFIG_POWER_BUTTON_INIT_TIMEOUT \
	CONFIG_PLATFORM_EC_POWER_BUTTON_INIT_TIMEOUT
#endif

#undef CONFIG_BUTTON_DEBOUNCE
#define CONFIG_BUTTON_DEBOUNCE CONFIG_PLATFORM_EC_BUTTON_DEBOUNCE

#undef CONFIG_POWERSEQ_FAKE_CONTROL
#ifdef CONFIG_PLATFORM_EC_POWERSEQ_FAKE_CONTROL
#define CONFIG_POWERSEQ_FAKE_CONTROL
#endif

#undef CONFIG_FAKE_SHMEM
#ifdef CONFIG_ARCH_POSIX
#define CONFIG_FAKE_SHMEM
#endif

#undef CONFIG_CMD_S5_TIMEOUT
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_S5_TIMEOUT
#define CONFIG_CMD_S5_TIMEOUT
#endif

#undef CONFIG_CMD_SHMEM
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_SHMEM
#define CONFIG_CMD_SHMEM
#endif

#undef CONFIG_CROS_FWID_VERSION
#ifdef CONFIG_PLATFORM_EC_CROS_FWID_VERSION
#define CONFIG_CROS_FWID_VERSION
#endif

#ifdef CONFIG_PLATFORM_EC_TIMER
#define CONFIG_HWTIMER_64BIT
#define CONFIG_HW_SPECIFIC_UDELAY
#endif /* CONFIG_PLATFORM_EC_TIMER */

#undef CONFIG_CMD_GETTIME
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_GETTIME
#define CONFIG_CMD_GETTIME
#endif /* CONFIG_PLATFORM_EC_CONSOLE_CMD_GETTIME */

#undef CONFIG_CMD_TIMERINFO
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_TIMERINFO
#define CONFIG_CMD_TIMERINFO
#endif /* CONFIG_PLATFORM_EC_CONSOLE_CMD_TIMERINFO */

#undef CONFIG_CMD_WAITMS
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_WAITMS
#define CONFIG_CMD_WAITMS
#endif /* CONFIG_PLATFORM_EC_CONSOLE_CMD_TIMERINFO */

/* USB-C things */
#ifdef CONFIG_PLATFORM_EC_USBC

#undef CONFIG_USB_PD_TCPMV2
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPMV2
#define CONFIG_USB_PD_TCPMV2
#endif

#undef CONFIG_USB_PD_CONTROLLER
#ifdef CONFIG_PLATFORM_EC_USB_PD_CONTROLLER
#define CONFIG_USB_PD_CONTROLLER
#endif

/*
 * Define these here for now. They are not actually CONFIG options in the EC
 * code base. Ideally they would be defined in the devicetree (perhaps for a
 * 'board' driver if not in the USB chip driver itself). Use Kconfig to allow
 * projects to overwrite the power configurations.
 *
 * SN5S30 PPC supports up to 24V VBUS source and sink, however passive USB-C
 * cables only support up to 60W.
 */
#define PD_OPERATING_POWER_MW CONFIG_PLATFORM_EC_PD_OPERATING_POWER_MW
#define PD_MAX_POWER_MW CONFIG_PLATFORM_EC_PD_MAX_POWER_MW
#define PD_MAX_CURRENT_MA CONFIG_PLATFORM_EC_PD_MAX_CURRENT_MA
#define PD_MAX_VOLTAGE_MV CONFIG_PLATFORM_EC_PD_MAX_VOLTAGE_MV

#define PD_POWER_SUPPLY_TURN_ON_DELAY \
	CONFIG_PLATFORM_EC_PD_POWER_SUPPLY_TURN_ON_DELAY
#define PD_POWER_SUPPLY_TURN_OFF_DELAY \
	CONFIG_PLATFORM_EC_PD_POWER_SUPPLY_TURN_OFF_DELAY
#endif /* CONFIG_PLATFORM_EC_USBC */

#undef CONFIG_EXTPOWER_DEBOUNCE_MS
#define CONFIG_EXTPOWER_DEBOUNCE_MS CONFIG_PLATFORM_EC_EXTPOWER_DEBOUNCE_MS

#undef CONFIG_CMD_PPC_DUMP
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_PPC_DUMP
#define CONFIG_CMD_PPC_DUMP
#endif

#undef CONFIG_USBC_PPC_LOGGING
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_LOGGING
#define CONFIG_USBC_PPC_LOGGING
#endif

#undef CONFIG_CMD_TCPC_DUMP
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_TCPC_DUMP
#define CONFIG_CMD_TCPC_DUMP
#endif

#undef CONFIG_USB_POWER_DELIVERY
#ifdef CONFIG_PLATFORM_EC_USB_POWER_DELIVERY
#define CONFIG_USB_POWER_DELIVERY
#endif

#undef CONFIG_CHARGE_MANAGER
#ifdef CONFIG_PLATFORM_EC_CHARGE_MANAGER
#define CONFIG_CHARGE_MANAGER

/* TODO: Put these charger defines in the devicetree? */
#define CONFIG_CHARGER_SENSE_RESISTOR 10
#define CONFIG_CHARGER_SENSE_RESISTOR_AC 10
#endif /* CONFIG_PLATFORM_EC_CHARGE_MANAGER */

#undef CONFIG_CHARGER
#ifdef CONFIG_PLATFORM_EC_CHARGER
#define CONFIG_CHARGER
#endif

#undef CONFIG_CHARGE_STATE_DEBUG
#ifdef CONFIG_PLATFORM_EC_CHARGE_STATE_DEBUG
#define CONFIG_CHARGE_STATE_DEBUG
#endif

#undef CONFIG_CHARGE_DEBUG
#ifdef CONFIG_PLATFORM_EC_CHARGE_DEBUG
#define CONFIG_CHARGE_DEBUG
#endif

#undef CONFIG_CMD_PWR_AVG
#ifdef CONFIG_PLATFORM_EC_CMD_PWR_AVG
#define CONFIG_CMD_PWR_AVG
#endif

#undef CONFIG_CHARGESPLASH
#ifdef CONFIG_PLATFORM_EC_CHARGESPLASH
#define CONFIG_CHARGESPLASH
#endif

#undef CONFIG_CHARGESPLASH_PERIOD
#ifdef CONFIG_PLATFORM_EC_CHARGESPLASH_PERIOD
#define CONFIG_CHARGESPLASH_PERIOD CONFIG_PLATFORM_EC_CHARGESPLASH_PERIOD
#endif

#undef CONFIG_CHARGESPLASH_MAX_REQUESTS_PER_PERIOD
#ifdef CONFIG_PLATFORM_EC_CHARGESPLASH_MAX_REQUESTS_PER_PERIOD
#define CONFIG_CHARGESPLASH_MAX_REQUESTS_PER_PERIOD \
	CONFIG_PLATFORM_EC_CHARGESPLASH_MAX_REQUESTS_PER_PERIOD
#endif

#undef CONFIG_CHARGER_DEFAULT_CURRENT_LIMIT
#ifdef CONFIG_PLATFORM_EC_CHARGER_DEFAULT_CURRENT_LIMIT
#define CONFIG_CHARGER_DEFAULT_CURRENT_LIMIT \
	CONFIG_PLATFORM_EC_CHARGER_DEFAULT_CURRENT_LIMIT
#endif

#undef CONFIG_CHARGER_MIN_INPUT_CURRENT_LIMIT
#ifdef CONFIG_PLATFORM_EC_CHARGER_MIN_INPUT_CURRENT_LIMIT
#define CONFIG_CHARGER_MIN_INPUT_CURRENT_LIMIT \
	CONFIG_PLATFORM_EC_CHARGER_MIN_INPUT_CURRENT_LIMIT
#endif

#undef CONFIG_CHARGER_INPUT_CURRENT_DERATE_PCT
#ifdef CONFIG_PLATFORM_EC_CHARGER_INPUT_CURRENT_DERATE_PCT
#define CONFIG_CHARGER_INPUT_CURRENT_DERATE_PCT \
	CONFIG_PLATFORM_EC_CHARGER_INPUT_CURRENT_DERATE_PCT
#endif

#undef CONFIG_CHARGER_MIN_BAT_PCT_FOR_POWER_ON
#ifdef CONFIG_PLATFORM_EC_CHARGER_MIN_BAT_PCT_FOR_POWER_ON
#define CONFIG_CHARGER_MIN_BAT_PCT_FOR_POWER_ON \
	CONFIG_PLATFORM_EC_CHARGER_MIN_BAT_PCT_FOR_POWER_ON
#endif

#undef CONFIG_CHARGER_MIN_BAT_PCT_FOR_POWER_ON_WITH_AC
#ifdef CONFIG_PLATFORM_EC_CHARGER_MIN_BAT_PCT_FOR_POWER_ON_WITH_AC
#define CONFIG_CHARGER_MIN_BAT_PCT_FOR_POWER_ON_WITH_AC \
	CONFIG_PLATFORM_EC_CHARGER_MIN_BAT_PCT_FOR_POWER_ON_WITH_AC
#endif

#undef CONFIG_CHARGER_MIN_POWER_MW_FOR_POWER_ON_WITH_BATT
#ifdef CONFIG_PLATFORM_EC_CHARGER_MIN_POWER_MW_FOR_POWER_ON_WITH_BATT
#define CONFIG_CHARGER_MIN_POWER_MW_FOR_POWER_ON_WITH_BATT \
	CONFIG_PLATFORM_EC_CHARGER_MIN_POWER_MW_FOR_POWER_ON_WITH_BATT
#endif

#undef CONFIG_CHARGER_MIN_POWER_MW_FOR_POWER_ON
#ifdef CONFIG_PLATFORM_EC_CHARGER_MIN_POWER_MW_FOR_POWER_ON
#define CONFIG_CHARGER_MIN_POWER_MW_FOR_POWER_ON \
	CONFIG_PLATFORM_EC_CHARGER_MIN_POWER_MW_FOR_POWER_ON
#endif

#undef CONFIG_CHARGER_SET_FREQUENCY
#ifdef CONFIG_PLATFORM_EC_CHARGER_SET_FREQUENCY
#define CONFIG_CHARGER_SET_FREQUENCY
#endif

#undef CONFIG_CHARGE_RAMP_SW
#ifdef CONFIG_PLATFORM_EC_CHARGE_RAMP_SW
#define CONFIG_CHARGE_RAMP_SW
#endif

#undef CONFIG_CHARGE_RAMP_HW
#ifdef CONFIG_PLATFORM_EC_CHARGE_RAMP_HW
#define CONFIG_CHARGE_RAMP_HW
#endif

#undef CONFIG_CMD_CHGRAMP
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_CHGRAMP
#define CONFIG_CMD_CHGRAMP
#endif

#undef CONFIG_CMD_CHARGER_DUMP
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_CHARGER_DUMP
#define CONFIG_CMD_CHARGER_DUMP
#endif

#undef CONFIG_USB_PID
#ifdef CONFIG_PLATFORM_EC_USB_PID
#define CONFIG_USB_PID CONFIG_PLATFORM_EC_USB_PID
#endif

#undef CONFIG_USB_BCD_DEV
#ifdef CONFIG_PLATFORM_EC_USB_BCD_DEV
#define CONFIG_USB_BCD_DEV CONFIG_PLATFORM_EC_USB_BCD_DEV
#endif

#undef CONFIG_USB_VID
#ifdef CONFIG_PLATFORM_EC_USB_VID
#define CONFIG_USB_VID CONFIG_PLATFORM_EC_USB_VID
#endif

#undef CONFIG_USB_MS_EXTENDED_COMPAT_ID_DESCRIPTOR
#ifdef CONFIG_PLATFORM_EC_USB_MS_EXTENDED_COMPAT_ID_DESCRIPTOR
#define CONFIG_USB_MS_EXTENDED_COMPAT_ID_DESCRIPTOR \
	CONFIG_PLATFORM_EC_USB_MS_EXTENDED_COMPAT_ID_DESCRIPTOR
#endif

/* VBUS-voltage measurement */
#undef CONFIG_USB_PD_VBUS_MEASURE_NOT_PRESENT
#ifdef CONFIG_PLATFORM_EC_USB_PD_VBUS_MEASURE_NOT_PRESENT
#define CONFIG_USB_PD_VBUS_MEASURE_NOT_PRESENT
#endif

#undef CONFIG_USB_PD_VBUS_MEASURE_CHARGER
#ifdef CONFIG_PLATFORM_EC_USB_PD_VBUS_MEASURE_CHARGER
#define CONFIG_USB_PD_VBUS_MEASURE_CHARGER
#endif

#undef CONFIG_USB_PD_VBUS_MEASURE_TCPC
#ifdef CONFIG_PLATFORM_EC_USB_PD_VBUS_MEASURE_TCPC
#define CONFIG_USB_PD_VBUS_MEASURE_TCPC
#endif

#undef CONFIG_USB_PD_VBUS_MEASURE_ADC_EACH_PORT
#ifdef CONFIG_PLATFORM_EC_USB_PD_VBUS_MEASURE_ADC_EACH_PORT
#define CONFIG_USB_PD_VBUS_MEASURE_ADC_EACH_PORT
#endif

#undef CONFIG_USB_PD_VBUS_MEASURE_BY_BOARD
#ifdef CONFIG_PLATFORM_EC_USB_PD_VBUS_MEASURE_BY_BOARD
#define CONFIG_USB_PD_VBUS_MEASURE_BY_BOARD
#endif

#undef CONFIG_CMD_VBUS
#ifdef CONFIG_PLATFORM_EC_CMD_VBUS
#define CONFIG_CMD_VBUS
#endif

#undef CONFIG_USB_CHARGER
#ifdef CONFIG_PLATFORM_EC_USB_CHARGER
#define CONFIG_USB_CHARGER
#endif

#undef CONFIG_USB_PORT_ENABLE_DYNAMIC
#ifdef CONFIG_PLATFORM_EC_USB_PORT_ENABLE_DYNAMIC
#define CONFIG_USB_PORT_ENABLE_DYNAMIC
#endif

#undef CONFIG_USB_PORT_POWER_DUMB
#ifdef CONFIG_PLATFORM_EC_USB_PORT_POWER_DUMB
#define CONFIG_USB_PORT_POWER_DUMB
/* usb_charge.h sets USB_PORT_ENABLE_COUNT from this for POWER_DUMB */
#define USB_PORT_COUNT                                                         \
	COND_CODE_1(DT_NODE_EXISTS(DT_INST(0, cros_ec_usba_port_enable_pins)), \
		    (DT_PROP_LEN(DT_INST(0, cros_ec_usba_port_enable_pins),    \
				 enable_pins)),                                \
		    (0))
#endif

#undef CONFIG_USB_PORT_POWER_DUMB_CUSTOM_HOOK
#ifdef CONFIG_PLATFORM_EC_USB_PORT_POWER_DUMB_CUSTOM_HOOK
#define CONFIG_USB_PORT_POWER_DUMB_CUSTOM_HOOK
#endif

#undef CONFIG_USB_PORT_POWER_SMART
#ifdef CONFIG_PLATFORM_EC_USB_PORT_POWER_SMART
#define CONFIG_USB_PORT_POWER_SMART
#undef CONFIG_USB_PORT_POWER_SMART_PORT_COUNT /* override config.h default */
/* usb_charge.h sets USB_PORT_ENABLE_COUNT from this for POWER_SMART */
#define CONFIG_USB_PORT_POWER_SMART_PORT_COUNT                                 \
	COND_CODE_1(DT_NODE_EXISTS(DT_INST(0, cros_ec_usba_port_enable_pins)), \
		    (DT_PROP_LEN(DT_INST(0, cros_ec_usba_port_enable_pins),    \
				 enable_pins)),                                \
		    (0))
#endif

#undef CONFIG_USB_PORT_POWER_SMART_CDP_SDP_ONLY
#ifdef CONFIG_PLATFORM_EC_USB_PORT_POWER_SMART_CDP_SDP_ONLY
#define CONFIG_USB_PORT_POWER_SMART_CDP_SDP_ONLY
#endif

#undef CONFIG_USB_PORT_POWER_SMART_SIMPLE
#ifdef CONFIG_PLATFORM_EC_USB_PORT_POWER_SMART_SIMPLE
#define CONFIG_USB_PORT_POWER_SMART_SIMPLE
#endif

#undef CONFIG_USB_PORT_POWER_SMART_DEFAULT_MODE
#ifdef CONFIG_PLATFORM_EC_USB_PORT_POWER_SMART_DEFAULT_DISABLED
#define CONFIG_USB_PORT_POWER_SMART_DEFAULT_MODE USB_CHARGE_MODE_DISABLED
#endif

#ifdef CONFIG_PLATFORM_EC_USB_PORT_POWER_SMART_DEFAULT_SDP
#define CONFIG_USB_PORT_POWER_SMART_DEFAULT_MODE USB_CHARGE_MODE_SDP2
#endif

#ifdef CONFIG_PLATFORM_EC_USB_PORT_POWER_SMART_DEFAULT_CDP
#define CONFIG_USB_PORT_POWER_SMART_DEFAULT_MODE USB_CHARGE_MODE_CDP
#endif

#undef CONFIG_USB_PORT_POWER_SMART_INVERTED
#ifdef CONFIG_PLATFORM_EC_USB_PORT_POWER_SMART_INVERTED
#define CONFIG_USB_PORT_POWER_SMART_INVERTED
#endif

#undef CONFIG_BC12_DETECT_RT1718S
#ifdef CONFIG_PLATFORM_EC_BC12_DETECT_RT1718S
#define CONFIG_BC12_DETECT_RT1718S
#endif

#undef CONFIG_BC12_CLIENT_MODE_ONLY_PI3USB9201
#ifdef CONFIG_PLATFORM_EC_BC12_CLIENT_MODE_ONLY_PI3USB9201
#define CONFIG_BC12_CLIENT_MODE_ONLY_PI3USB9201
#endif

#undef CONFIG_BC12_DETECT_PI3USB9201
#ifdef CONFIG_PLATFORM_EC_BC12_DETECT_PI3USB9201
#define CONFIG_BC12_DETECT_PI3USB9201
#endif

#undef CONFIG_BC12_DETECT_MT6360
#ifdef CONFIG_PLATFORM_EC_BC12_DETECT_MT6360
#define CONFIG_BC12_DETECT_MT6360
#endif

#undef CONFIG_BC12_DETECT_DATA_ROLE_TRIGGER
#ifdef CONFIG_PLATFORM_EC_BC12_DETECT_DATA_ROLE_TRIGGER
#define CONFIG_BC12_DETECT_DATA_ROLE_TRIGGER
#endif

#undef CONFIG_MT6360_BC12_GPIO
#ifdef CONFIG_PLATFORM_EC_MT6360_BC12_GPIO
#define CONFIG_MT6360_BC12_GPIO
#endif

#undef CONFIG_HOSTCMD_REGULATOR
#ifdef CONFIG_PLATFORM_EC_HOSTCMD_REGULATOR
#define CONFIG_HOSTCMD_REGULATOR
#endif

#undef CONFIG_USB_PD_DUAL_ROLE
#ifdef CONFIG_PLATFORM_EC_USB_PD_DUAL_ROLE
#define CONFIG_USB_PD_DUAL_ROLE
#endif

#undef CONFIG_USB_PD_DUAL_ROLE_AUTO_TOGGLE
#ifdef CONFIG_PLATFORM_EC_USB_PD_DUAL_ROLE_AUTO_TOGGLE
#define CONFIG_USB_PD_DUAL_ROLE_AUTO_TOGGLE
#endif

#undef CONFIG_USB_PD_DISCHARGE
#if defined(CONFIG_PLATFORM_EC_USB_PD_DISCHARGE) || \
	defined(CONFIG_TEST_ENABLE_USB_PD_DISCHARGE)
#define CONFIG_USB_PD_DISCHARGE
#endif

#undef CONFIG_USB_PD_DISCHARGE_GPIO
#ifdef CONFIG_PLATFORM_EC_USB_PD_DISCHARGE_GPIO
#define CONFIG_USB_PD_DISCHARGE_GPIO
#endif

#undef CONFIG_USB_PD_DISCHARGE_TCPC
#ifdef CONFIG_PLATFORM_EC_USB_PD_DISCHARGE_TCPC
#define CONFIG_USB_PD_DISCHARGE_TCPC
#endif

#undef CONFIG_USB_PD_DISCHARGE_PPC
#ifdef CONFIG_PLATFORM_EC_USB_PD_DISCHARGE_PPC
#define CONFIG_USB_PD_DISCHARGE_PPC
#endif

#undef CONFIG_USB_PD_LOGGING
#ifdef CONFIG_PLATFORM_EC_USB_PD_LOGGING
#define CONFIG_USB_PD_LOGGING
#endif

#undef CONFIG_USB_PD_PRL_EVENT_LOG
#ifdef CONFIG_PLATFORM_EC_USB_PD_PRL_EVENT_LOG
#define CONFIG_USB_PD_PRL_EVENT_LOG
#endif

#undef CONFIG_USB_PD_PRL_EVENT_LOG_CAPACITY
#ifdef CONFIG_PLATFORM_EC_USB_PD_PRL_EVENT_LOG_CAPACITY
#define CONFIG_USB_PD_PRL_EVENT_LOG_CAPACITY \
	CONFIG_PLATFORM_EC_USB_PD_PRL_EVENT_LOG_CAPACITY
#endif

#undef CONFIG_USBC_OCP
#ifdef CONFIG_PLATFORM_EC_USBC_OCP
#define CONFIG_USBC_OCP
#endif

#undef CONFIG_USB_PD_CONSOLE_CMD
#ifdef CONFIG_PLATFORM_EC_USB_PD_CONSOLE_CMD
#define CONFIG_USB_PD_CONSOLE_CMD
#endif

#undef CONFIG_USB_PD_HOST_CMD
#if defined(CONFIG_PLATFORM_EC_USB_PD_HOST_CMD) || \
	defined(CONFIG_TEST_ENABLE_USB_PD_HOST_CMD)
#define CONFIG_USB_PD_HOST_CMD
#endif

#undef CONFIG_HOSTCMD_PD_CHIP_INFO
#ifdef CONFIG_PLATFORM_EC_HOSTCMD_PD_CHIP_INFO
#define CONFIG_HOSTCMD_PD_CHIP_INFO
#endif

#undef CONFIG_HOSTCMD_RWHASHPD
#ifdef CONFIG_PLATFORM_EC_HOSTCMD_RWHASHPD
#define CONFIG_HOSTCMD_RWHASHPD
#endif

#undef CONFIG_HOSTCMD_TYPEC_DISCOVERY
#ifdef CONFIG_PLATFORM_EC_HOSTCMD_TYPEC_DISCOVERY
#define CONFIG_HOSTCMD_TYPEC_DISCOVERY
#endif

#undef CONFIG_HOSTCMD_TYPEC_CONTROL
#ifdef CONFIG_PLATFORM_EC_HOSTCMD_TYPEC_CONTROL
#define CONFIG_HOSTCMD_TYPEC_CONTROL
#endif

#undef CONFIG_HOSTCMD_TYPEC_STATUS
#ifdef CONFIG_PLATFORM_EC_HOSTCMD_TYPEC_STATUS
#define CONFIG_HOSTCMD_TYPEC_STATUS
#endif

#undef CONFIG_USB_PD_REV30
#ifdef CONFIG_PLATFORM_EC_USB_PD_REV30
#define CONFIG_USB_PD_REV30
#endif

#undef CONFIG_USB_PD_EXTENDED_MESSAGES
#ifdef CONFIG_PLATFORM_EC_USB_PD_EXTENDED_MESSAGES
#define CONFIG_USB_PD_EXTENDED_MESSAGES
#endif

#undef CONFIG_USB_PD_VBUS_DETECT_TCPC
#undef CONFIG_USB_PD_VBUS_DETECT_GPIO
#ifdef CONFIG_PLATFORM_EC_USB_PD_VBUS_DETECT_TCPC
#define CONFIG_USB_PD_VBUS_DETECT_TCPC
#endif

#undef CONFIG_USB_PD_VBUS_DETECT_CHARGER
#ifdef CONFIG_PLATFORM_EC_USB_PD_VBUS_DETECT_CHARGER
#define CONFIG_USB_PD_VBUS_DETECT_CHARGER
#endif

#undef CONFIG_USB_PD_VBUS_DETECT_PPC
#ifdef CONFIG_PLATFORM_EC_USB_PD_VBUS_DETECT_PPC
#define CONFIG_USB_PD_VBUS_DETECT_PPC
#endif

#undef CONFIG_USB_PD_VBUS_DETECT_NONE
#ifdef CONFIG_PLATFORM_EC_USB_PD_VBUS_DETECT_NONE
#define CONFIG_USB_PD_VBUS_DETECT_NONE
#endif

#undef CONFIG_USB_PD_5V_EN_CUSTOM
#ifdef CONFIG_PLATFORM_EC_USB_PD_5V_EN_CUSTOM
#define CONFIG_USB_PD_5V_EN_CUSTOM
#endif

#undef CONFIG_USB_PD_5V_CHARGER_CTRL
#ifdef CONFIG_PLATFORM_EC_USB_PD_5V_CHARGER_CTRL
#define CONFIG_USB_PD_5V_CHARGER_CTRL
#endif

#undef CONFIG_USB_TYPEC_SM
#ifdef CONFIG_PLATFORM_EC_USB_TYPEC_SM
#define CONFIG_USB_TYPEC_SM
#endif

#undef CONFIG_USB_PRL_SM
#ifdef CONFIG_PLATFORM_EC_USB_PRL_SM
#define CONFIG_USB_PRL_SM
#endif

#undef CONFIG_USB_PE_SM
#ifdef CONFIG_PLATFORM_EC_USB_PE_SM
#define CONFIG_USB_PE_SM
#endif

#undef CONFIG_USB_DPM_SM
#ifdef CONFIG_PLATFORM_EC_USB_DPM_SM
#define CONFIG_USB_DPM_SM
#endif

#undef CONFIG_USB_PD_DECODE_SOP
#ifdef CONFIG_PLATFORM_EC_USB_PD_DECODE_SOP
#define CONFIG_USB_PD_DECODE_SOP
#endif

#undef CONFIG_USB_VPD
#ifdef CONFIG_PLATFORM_EC_USB_VPD
#define CONFIG_USB_VPD
#endif

#undef CONFIG_USB_CTVPD
#ifdef CONFIG_PLATFORM_EC_USB_CTVPD
#define CONFIG_USB_CTVPD
#endif

#undef CONFIG_USB_DRP_ACC_TRYSRC
#ifdef CONFIG_PLATFORM_EC_USB_DRP_ACC_TRYSRC
#define CONFIG_USB_DRP_ACC_TRYSRC
#endif

#undef CONFIG_USB_PD_TCPM_FUSB302
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_FUSB302
#define CONFIG_USB_PD_TCPM_FUSB302
#endif

#undef CONFIG_USB_PD_TCPM_NCT38XX
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_NCT38XX
#define CONFIG_USB_PD_TCPM_NCT38XX
#endif

#undef CONFIG_USB_PD_TCPM_PS8745
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_PS8745
#define CONFIG_USB_PD_TCPM_PS8745
#endif

#undef CONFIG_USB_PD_TCPM_PS8745_FORCE_ID
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_PS8745_FORCE_ID
#define CONFIG_USB_PD_TCPM_PS8745_FORCE_ID
#endif

#undef CONFIG_USB_PD_TCPM_PS8751
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_PS8751
#define CONFIG_USB_PD_TCPM_PS8751
#endif

#undef CONFIG_USB_PD_TCPM_PS8805
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_PS8805
#define CONFIG_USB_PD_TCPM_PS8805
#endif

#undef CONFIG_USB_PD_TCPM_PS8805_FORCE_DID
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_PS8805_FORCE_DID
#define CONFIG_USB_PD_TCPM_PS8805_FORCE_DID
#endif

#undef CONFIG_USB_PD_TCPM_PS8815
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_PS8815
#define CONFIG_USB_PD_TCPM_PS8815
#endif

#undef CONFIG_USB_PD_TCPM_PS8815_FORCE_DID
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_PS8815_FORCE_DID
#define CONFIG_USB_PD_TCPM_PS8815_FORCE_DID
#endif

#undef CONFIG_USB_PD_TCPM_MULTI_PS8XXX
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_MULTI_PS8XXX
#define CONFIG_USB_PD_TCPM_MULTI_PS8XXX
#endif

#undef CONFIG_USB_PD_TCPM_RT1715
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_RT1715
#define CONFIG_USB_PD_TCPM_RT1715
#endif

#undef CONFIG_USB_PD_TCPM_RT1718S
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_RT1718S
#define CONFIG_USB_PD_TCPM_RT1718S
#endif

#undef CONFIG_USB_PD_TCPM_TUSB422
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_TUSB422
#define CONFIG_USB_PD_TCPM_TUSB422
#endif

#undef CONFIG_USB_PD_TCPM_TCPCI
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_TCPCI
#define CONFIG_USB_PD_TCPM_TCPCI
#endif

#undef CONFIG_USB_PD_TCPM_ITE_ON_CHIP
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_ITE_ON_CHIP
#define CONFIG_USB_PD_TCPM_ITE_ON_CHIP

#define IT83XX_USBPD_PHY_PORT_COUNT \
	COND_CODE_1(DT_NODE_EXISTS(DT_INST(1, ite_it8xxx2_usbpd)), (2), (1))

#define CONFIG_USB_PD_ITE_ACTIVE_PORT_COUNT \
	DT_NUM_INST_STATUS_OKAY(ite_it8xxx2_usbpd)
#endif

#undef CONFIG_USB_PD_TCPM_DRIVER_IT8XXX2
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_DRIVER_IT8XXX2
#define CONFIG_USB_PD_TCPM_DRIVER_IT8XXX2
#ifdef CONFIG_SOC_IT8XXX2_USBPD_PHY_V1
/* Individual setting CC1 and CC2 resistance. */
#define IT83XX_USBPD_CC1_CC2_RESISTANCE_SEPARATE
#elif defined(CONFIG_SOC_IT8XXX2_USBPD_PHY_V2)
/* CCGCR 04h bit[3,2,1] Rp 3A value is changed to 000b. */
#define IT8XXX2_USBPD_RP_3A0_VALUE_IS_ZERO
/*
 * CCGCR 04h bit[7] is reserved, so we control the power of cc analog module
 * by CCCSR 05h bit[7,3].
 */
#define IT8XXX2_USBPD_CCGCR_BIT7_RESERVED
#endif
#endif

#undef CONFIG_USB_PD_TCPM_DRIVER_IT83XX
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_DRIVER_IT83XX
#define CONFIG_USB_PD_TCPM_DRIVER_IT83XX
#endif

#undef CONFIG_IT83XX_TUNE_CC_PHY
#ifdef CONFIG_PLATFORM_EC_IT83XX_TUNE_CC_PHY
#define CONFIG_IT83XX_TUNE_CC_PHY
#endif

#undef CONFIG_USB_PD_TCPM_RAA489000
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_RAA489000
#define CONFIG_USB_PD_TCPM_RAA489000
#endif

#undef CONFIG_USB_PD_TCPM_ANX7447
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_ANX7447
#define CONFIG_USB_PD_TCPM_ANX7447
#endif

#undef CONFIG_USB_PD_TCPM_ANX7447_AUX_PU_PD
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_ANX7447_AUX_PU_PD
#define CONFIG_USB_PD_TCPM_ANX7447_AUX_PU_PD
#endif

#undef CONFIG_USB_PD_TCPM_ANX7447_OCM_ERASE_COMMAND
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_ANX7447_OCM_ERASE_COMMAND
#define CONFIG_USB_PD_TCPM_ANX7447_OCM_ERASE_COMMAND
#endif

#undef CONFIG_USB_PD_PORT_MAX_COUNT
#define CONFIG_USB_PD_PORT_MAX_COUNT DT_NUM_INST_STATUS_OKAY(named_usbc_port)

#if defined(CONFIG_PLATFORM_EC_USB_POWER_DELIVERY) && \
	defined(CONFIG_PLATFORM_EC_USB_PD_TCPMV2)
/* USBC-PD Port 0 */
#if CONFIG_USB_PD_PORT_MAX_COUNT > 0
#define HAS_TASK_PD_C0 1

#ifndef CONFIG_PLATFORM_EC_USB_PD_PORT_0_SHARED
#define HAS_TASK_PD_INT_C0 1
#endif /* !CONFIG_PLATFORM_EC_USB_PD_PORT_0_SHARED */

#endif /* CONFIG_USB_PD_PORT_MAX_COUNT > 0 */

/* USBC-PD Port 1 */
#if CONFIG_USB_PD_PORT_MAX_COUNT > 1
#define HAS_TASK_PD_C1 1

#ifndef CONFIG_PLATFORM_EC_USB_PD_PORT_1_SHARED
#define HAS_TASK_PD_INT_C1 1
#endif /* !CONFIG_PLATFORM_EC_USB_PD_PORT_1_SHARED */

#endif /* CONFIG_USB_PD_PORT_MAX_COUNT > 1 */

/* USBC-PD Port 2 */
#if CONFIG_USB_PD_PORT_MAX_COUNT > 2
#define HAS_TASK_PD_C2 1

#ifndef CONFIG_PLATFORM_EC_USB_PD_PORT_2_SHARED
#define HAS_TASK_PD_INT_C2 1
#endif /* !CONFIG_PLATFORM_EC_USB_PD_PORT_2_SHARED */

#endif /* CONFIG_USB_PD_PORT_MAX_COUNT > 2 */

/* USBC-PD Port 3 */
#if CONFIG_USB_PD_PORT_MAX_COUNT > 3
#define HAS_TASK_PD_C3 1

#ifndef CONFIG_PLATFORM_EC_USB_PD_PORT_3_SHARED
#define HAS_TASK_PD_INT_C3 1
#endif /* !CONFIG_PLATFORM_EC_USB_PD_PORT_3_SHARED */

#endif /* CONFIG_USB_PD_PORT_MAX_COUNT > 3 */

#endif /* CONFIG_PLATFORM_EC_USB_POWER_DELIVERY */

/* Remove PD_INT_C* task for ports managed by ITE embedded TCPC */
#ifdef CONFIG_USB_PD_ITE_ACTIVE_PORT_COUNT
#if CONFIG_USB_PD_ITE_ACTIVE_PORT_COUNT >= 1
#undef HAS_TASK_PD_INT_C0
#endif
#if CONFIG_USB_PD_ITE_ACTIVE_PORT_COUNT >= 2
#undef HAS_TASK_PD_INT_C1
#endif
#if CONFIG_USB_PD_ITE_ACTIVE_PORT_COUNT >= 3
#undef HAS_TASK_PD_INT_C2
#endif
#if CONFIG_USB_PD_ITE_ACTIVE_PORT_COUNT >= 4
#undef HAS_TASK_PD_INT_C3
#endif
#endif /* CONFIG_USB_PD_ITE_ACTIVE_PORT_COUNT */

#undef CONFIG_USB_PD_PPC
#ifdef CONFIG_PLATFORM_EC_USB_PD_PPC
#define CONFIG_USB_PD_PPC
#endif

#undef CONFIG_USBC_PPC
#ifdef CONFIG_PLATFORM_EC_USBC_PPC
#define CONFIG_USBC_PPC
#endif

#undef CONFIG_USBC_PPC_AOZ1380
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_AOZ1380
#define CONFIG_USBC_PPC_AOZ1380
#endif

#undef CONFIG_USBC_PPC_KTU1125
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_KTU1125
#define CONFIG_USBC_PPC_KTU1125
#endif

#undef CONFIG_USBC_PPC_NX20P3481
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_NX20P3481
#define CONFIG_USBC_PPC_NX20P3481
#endif

#undef CONFIG_USBC_PPC_NX20P3483
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_NX20P3483
#define CONFIG_USBC_PPC_NX20P3483
#endif

#undef CONFIG_USBC_NX20P348X_RCP_5VSRC_MASK_ENABLE
#ifdef CONFIG_PLATFORM_EC_USBC_NX20P348X_RCP_5VSRC_MASK_ENABLE
#define CONFIG_USBC_NX20P348X_RCP_5VSRC_MASK_ENABLE
#endif

#undef CONFIG_USBC_PPC_RT1718S
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_RT1718S
#define CONFIG_USBC_PPC_RT1718S
#endif

#undef CONFIG_USBC_PPC_SN5S330
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_SN5S330
#define CONFIG_USBC_PPC_SN5S330
#endif

#undef CONFIG_USBC_PPC_SYV682X
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_SYV682X
#define CONFIG_USBC_PPC_SYV682X
#endif

#undef CONFIG_USBC_PPC_SYV682C
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_SYV682C
#define CONFIG_USBC_PPC_SYV682C
#endif

#undef CONFIG_SYV682X_HV_ILIM
#define CONFIG_SYV682X_HV_ILIM CONFIG_PLATFORM_EC_USBC_PPC_SYV682X_HV_ILIM

#undef CONFIG_USBC_PPC_SYV682X_NO_CC
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_SYV682X_NO_CC
#define CONFIG_USBC_PPC_SYV682X_NO_CC
#endif

#undef CONFIG_USBC_PPC_SYV682X_SMART_DISCHARGE
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_SYV682X_SMART_DISCHARGE
#define CONFIG_USBC_PPC_SYV682X_SMART_DISCHARGE
#endif

#undef CONFIG_USBC_PPC_SYV682X_OVP_SET_15V
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_SYV682X_OVP_SET_15V
#define CONFIG_USBC_PPC_SYV682X_OVP_SET_15V
#endif

#undef CONFIG_USB_PD_TCPC_RUNTIME_CONFIG
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPC_RUNTIME_CONFIG
#define CONFIG_USB_PD_TCPC_RUNTIME_CONFIG
#endif

#undef CONFIG_USB_MUX_RUNTIME_CONFIG
#ifdef CONFIG_PLATFORM_EC_USB_MUX_RUNTIME_CONFIG
#define CONFIG_USB_MUX_RUNTIME_CONFIG
#endif

#undef CONFIG_USB_PD_ALT_MODE
#ifdef CONFIG_PLATFORM_EC_USB_PD_ALT_MODE
#define CONFIG_USB_PD_ALT_MODE
#endif

#undef CONFIG_USB_PD_ALT_MODE_DFP
#ifdef CONFIG_PLATFORM_EC_USB_PD_ALT_MODE_DFP
#define CONFIG_USB_PD_ALT_MODE_DFP
#endif

#undef CONFIG_USB_PD_ALT_MODE_UFP
#ifdef CONFIG_PLATFORM_EC_USB_PD_ALT_MODE_UFP
#define CONFIG_USB_PD_ALT_MODE_UFP
#endif

#undef CONFIG_USB_PD_DISCOVERY
#ifdef CONFIG_PLATFORM_EC_USB_PD_DISCOVERY
#define CONFIG_USB_PD_DISCOVERY
#endif

#undef CONFIG_USB_PD_DP21_MODE
#ifdef CONFIG_PLATFORM_EC_USB_PD_DP21_MODE
#define CONFIG_USB_PD_DP21_MODE
#endif

#undef CONFIG_USB_PD_DPS
#ifdef CONFIG_PLATFORM_EC_USB_PD_DPS
#define CONFIG_USB_PD_DPS
#endif

#undef CONFIG_DP_REDRIVER_TDP142
#ifdef CONFIG_PLATFORM_EC_DP_REDRIVER_TDP142
#define CONFIG_DP_REDRIVER_TDP142
#endif

#undef CONFIG_USBC_RETIMER_FW_UPDATE
#ifdef CONFIG_PLATFORM_EC_USBC_RETIMER_FW_UPDATE
#define CONFIG_USBC_RETIMER_FW_UPDATE
#endif

#undef CONFIG_USBC_RETIMER_INTEL_BB
#ifdef CONFIG_PLATFORM_EC_USBC_RETIMER_INTEL_BB
#define CONFIG_USBC_RETIMER_INTEL_BB
#endif

#undef CONFIG_USBC_RETIMER_INTEL_HB
#ifdef CONFIG_PLATFORM_EC_USBC_RETIMER_INTEL_HB

#define USBC_PORT_C0_HB_RETIMER_I2C_ADDR \
	DT_REG_ADDR(DT_NODELABEL(usb_c0_hb_retimer))
#define USBC_PORT_C1_HB_RETIMER_I2C_ADDR \
	DT_REG_ADDR(DT_NODELABEL(usb_c1_hb_retimer))
#define USBC_PORT_C2_HB_RETIMER_I2C_ADDR \
	DT_REG_ADDR(DT_NODELABEL(usb_c2_hb_retimer))
#define USBC_PORT_C3_HB_RETIMER_I2C_ADDR \
	DT_REG_ADDR(DT_NODELABEL(usb_c3_hb_retimer))
#define CONFIG_USBC_RETIMER_INTEL_HB
#endif

#undef CONFIG_USBC_RETIMER_INTEL_BB_RUNTIME_CONFIG
#ifdef CONFIG_PLATFORM_EC_USBC_RETIMER_INTEL_BB_RUNTIME_CONFIG
#define CONFIG_USBC_RETIMER_INTEL_BB_RUNTIME_CONFIG
#endif

#undef CONFIG_USBC_RETIMER_INTEL_BB_VPRO_CAPABLE
#ifdef CONFIG_PLATFORM_EC_USBC_RETIMER_INTEL_BB_VPRO_CAPABLE
#define CONFIG_USBC_RETIMER_INTEL_BB_VPRO_CAPABLE
#endif

#undef CONFIG_USBC_RETIMER_ANX7451
#ifdef CONFIG_PLATFORM_EC_USBC_RETIMER_ANX7451
#define CONFIG_USBC_RETIMER_ANX7451
#endif

#undef CONFIG_USBC_RETIMER_ANX7483
#ifdef CONFIG_PLATFORM_EC_USBC_RETIMER_ANX7483
#define CONFIG_USBC_RETIMER_ANX7483
#endif

#undef CONFIG_USBC_RETIMER_ANX7452
#ifdef CONFIG_PLATFORM_EC_USBC_RETIMER_ANX7452
#define CONFIG_USBC_RETIMER_ANX7452
#endif

#undef CONFIG_USBC_RETIMER_KB8010
#ifdef CONFIG_PLATFORM_EC_USBC_RETIMER_KB8010
#define CONFIG_USBC_RETIMER_KB8010
#endif

#undef CONFIG_USBC_RETIMER_KB800X
#ifdef CONFIG_PLATFORM_EC_USBC_RETIMER_KB800X
#define CONFIG_USBC_RETIMER_KB800X
#endif

#undef CONFIG_USBC_RETIMER_PS8811
#ifdef CONFIG_PLATFORM_EC_USBC_RETIMER_PS8811
#define CONFIG_USBC_RETIMER_PS8811
#endif

#undef CONFIG_USBC_RETIMER_PS8818
#ifdef CONFIG_PLATFORM_EC_USBC_RETIMER_PS8818
#define CONFIG_USBC_RETIMER_PS8818
#endif

#undef CONFIG_CMD_RETIMER
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_RETIMER
#define CONFIG_CMD_RETIMER
#endif

#undef CONFIG_USBC_SS_MUX
#ifdef CONFIG_PLATFORM_EC_USBC_SS_MUX
#define CONFIG_USBC_SS_MUX
#endif

#undef CONFIG_USBC_SS_MUX_DFP_ONLY
#ifdef CONFIG_PLATFORM_EC_USBC_SS_MUX_DFP_ONLY
#define CONFIG_USBC_SS_MUX_DFP_ONLY
#endif

#undef CONFIG_USB_MUX_AP_CONTROL
#ifdef CONFIG_PLATFORM_EC_USB_MUX_AP_CONTROL
#define CONFIG_USB_MUX_AP_CONTROL
#endif

#undef CONFIG_USB_MUX_AMD_FP6
#ifdef CONFIG_PLATFORM_EC_USB_MUX_AMD_FP6
#define CONFIG_USB_MUX_AMD_FP6
#endif

#undef CONFIG_USB_MUX_IT5205
#ifdef CONFIG_PLATFORM_EC_USB_MUX_IT5205
#define CONFIG_USB_MUX_IT5205
#endif

#undef CONFIG_USB_MUX_PS8743
#ifdef CONFIG_PLATFORM_EC_USB_MUX_PS8743
#define CONFIG_USB_MUX_PS8743
#endif

#undef CONFIG_USB_MUX_TUSB546
#ifdef CONFIG_PLATFORM_EC_USB_MUX_TUSB546
#define CONFIG_USB_MUX_TUSB546
#endif

#undef CONFIG_USB_MUX_TUSB1044
#ifdef CONFIG_PLATFORM_EC_USB_MUX_TUSB1044
#define CONFIG_USB_MUX_TUSB1044
#endif

#undef CONFIG_USB_MUX_TUSB1064
#ifdef CONFIG_PLATFORM_EC_USB_MUX_TUSB1064
#define CONFIG_USB_MUX_TUSB1064
#endif

#undef CONFIG_USB_MUX_VIRTUAL
#ifdef CONFIG_PLATFORM_EC_USB_MUX_VIRTUAL
#define CONFIG_USB_MUX_VIRTUAL
#endif

#undef CONFIG_USB_PD_TCPM_MUX
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_MUX
#define CONFIG_USB_PD_TCPM_MUX
#endif

#undef CONFIG_USB_PD_TCPM_SBU
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPM_SBU
#define CONFIG_USB_PD_TCPM_SBU
#endif

#undef CONFIG_USBC_PPC_DEDICATED_INT
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_DEDICATED_INT
#define CONFIG_USBC_PPC_DEDICATED_INT
#endif

#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_PD
#define CONFIG_CONSOLE_CMD_PD
#endif

#ifdef CONFIG_HAS_TASK_PD_INT_C0
/* This must be defined if any task is active */
#define CONFIG_HAS_TASK_PD_INT
#endif

#undef CONFIG_MKBP_EVENT
#ifdef CONFIG_PLATFORM_EC_MKBP_EVENT
#define CONFIG_MKBP_EVENT
#endif

#undef CONFIG_MKBP_USE_GPIO
#ifdef CONFIG_PLATFORM_EC_MKBP_USE_GPIO
#define CONFIG_MKBP_USE_GPIO
#endif

#undef CONFIG_MKBP_USE_HOST_EVENT
#ifdef CONFIG_PLATFORM_EC_MKBP_USE_HOST_EVENT
#define CONFIG_MKBP_USE_HOST_EVENT
#endif

#undef CONFIG_MKBP_USE_HECI
#ifdef CONFIG_PLATFORM_EC_MKBP_USE_HECI
#define CONFIG_MKBP_USE_HECI
#endif

#undef CONFIG_MKBP_USE_GPIO_AND_HOST_EVENT
#ifdef CONFIG_PLATFORM_EC_MKBP_USE_GPIO_AND_HOST_EVENT
#define CONFIG_MKBP_USE_GPIO_AND_HOST_EVENT
#endif

#undef CONFIG_MKBP_USE_CUSTOM
#ifdef CONFIG_PLATFORM_EC_MKBP_USE_CUSTOM
#define CONFIG_MKBP_USE_CUSTOM
#endif

#undef CONFIG_MKBP_USE_GPIO_ACTIVE_HIGH
#ifdef CONFIG_PLATFORM_EC_MKBP_USE_GPIO_ACTIVE_HIGH
#define CONFIG_MKBP_USE_GPIO_ACTIVE_HIGH
#endif

#undef CONFIG_USB_PD_TCPC_LOW_POWER
#undef CONFIG_USB_PD_TCPC_LPM_EXIT_DEBOUNCE
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPC_LOW_POWER
#define CONFIG_USB_PD_TCPC_LOW_POWER
#define CONFIG_USB_PD_TCPC_LPM_EXIT_DEBOUNCE \
	CONFIG_PLATFORM_EC_USB_PD_TCPC_LPM_EXIT_DEBOUNCE_US
#endif /* CONFIG_PLATFORM_EC_USB_PD_TCPC_LOW_POWER */

#undef CONFIG_USB_PD_DEBUG_LEVEL
#ifdef CONFIG_PLATFORM_EC_USB_PD_DEBUG_FIXED_LEVEL
#define CONFIG_USB_PD_DEBUG_LEVEL CONFIG_PLATFORM_EC_USB_PD_DEBUG_LEVEL
#endif

#undef CONFIG_USB_PD_INITIAL_DEBUG_LEVEL
#ifdef CONFIG_PLATFORM_EC_USB_PD_INITIAL_DEBUG_LEVEL
#define CONFIG_USB_PD_INITIAL_DEBUG_LEVEL \
	CONFIG_PLATFORM_EC_USB_PD_INITIAL_DEBUG_LEVEL
#endif

#undef CONFIG_USB_PD_FLAGS
#ifdef CONFIG_PLATFORM_EC_USB_PD_FLAGS
#define CONFIG_USB_PD_FLAGS
#endif

#undef CONFIG_USB_PD_RUNTIME_FLAGS
#ifdef CONFIG_PLATFORM_EC_USB_PD_RUNTIME_FLAGS
#define CONFIG_USB_PD_RUNTIME_FLAGS
#endif

#undef CONFIG_USB_PD_STARTUP_DELAY_MS
#ifdef CONFIG_PLATFORM_EC_USB_PD_STARTUP_DELAY_MS
#define CONFIG_USB_PD_STARTUP_DELAY_MS \
	CONFIG_PLATFORM_EC_USB_PD_STARTUP_DELAY_MS
#endif

#undef CONFIG_USB_PD_3A_PORTS
#ifdef CONFIG_PLATFORM_EC_CONFIG_USB_PD_3A_PORTS
#define CONFIG_USB_PD_3A_PORTS CONFIG_PLATFORM_EC_CONFIG_USB_PD_3A_PORTS
#endif

#undef CONFIG_USB_PD_TEMP_SENSOR
#ifdef CONFIG_PLATFORM_EC_USB_PD_TEMP_SENSOR
#define CONFIG_USB_PD_TEMP_SENSOR CONFIG_PLATFORM_EC_USB_PD_TEMP_SENSOR
#endif

#undef CONFIG_USB_PD_SHORT_PRESS_MAX_MS
#ifdef CONFIG_PLATFORM_EC_USB_PD_SHORT_PRESS_MAX_MS
#define CONFIG_USB_PD_SHORT_PRESS_MAX_MS \
	CONFIG_PLATFORM_EC_USB_PD_SHORT_PRESS_MAX_MS
#endif

#undef CONFIG_USB_PD_LONG_PRESS_MAX_MS
#ifdef CONFIG_PLATFORM_EC_USB_PD_LONG_PRESS_MAX_MS
#define CONFIG_USB_PD_LONG_PRESS_MAX_MS \
	CONFIG_PLATFORM_EC_USB_PD_LONG_PRESS_MAX_MS
#endif

#undef CONFIG_USBC_VCONN
#ifdef CONFIG_PLATFORM_EC_USBC_VCONN
#define CONFIG_USBC_VCONN
#endif

#undef CONFIG_USBC_VCONN_SWAP
#ifdef CONFIG_PLATFORM_EC_USBC_VCONN_SWAP
#define CONFIG_USBC_VCONN_SWAP
#endif

#undef CONFIG_USB_PD_TRY_SRC
#ifdef CONFIG_PLATFORM_EC_USB_PD_TRY_SRC
#define CONFIG_USB_PD_TRY_SRC
#endif

#undef CONFIG_USBC_PPC_POLARITY
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_POLARITY
#define CONFIG_USBC_PPC_POLARITY
#endif

#undef CONFIG_USBC_PPC_SBU
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_SBU
#define CONFIG_USBC_PPC_SBU
#endif

#undef CONFIG_USBC_PPC_VCONN
#ifdef CONFIG_PLATFORM_EC_USBC_PPC_VCONN
#define CONFIG_USBC_PPC_VCONN
#endif

#undef CONFIG_USB_PD_USB32_DRD
#ifdef CONFIG_PLATFORM_EC_USB_PD_USB32_DRD
#define CONFIG_USB_PD_USB32_DRD
#endif

#undef CONFIG_HOSTCMD_PD_CONTROL
#ifdef CONFIG_PLATFORM_EC_HOSTCMD_PD_CONTROL
#define CONFIG_HOSTCMD_PD_CONTROL
#endif

#undef CONFIG_CMD_HCDEBUG
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_HCDEBUG
#define CONFIG_CMD_HCDEBUG
#endif

#undef CONFIG_CMD_POWERINDEBUG
#ifdef CONFIG_PLATFORM_EC_CMD_POWERINDEBUG
#define CONFIG_CMD_POWERINDEBUG
#endif

#undef CONFIG_CMD_USB_PD_PE
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_USB_PD_PE
#define CONFIG_CMD_USB_PD_PE
#endif

#undef CONFIG_CMD_USB_PD_CABLE
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_USB_PD_CABLE
#define CONFIG_CMD_USB_PD_CABLE
#endif

#undef CONFIG_USB_PD_DP_MODE
#ifdef CONFIG_PLATFORM_EC_USB_PD_DP_MODE
#define CONFIG_USB_PD_DP_MODE
#endif

#undef CONFIG_USB_PD_TBT_COMPAT_MODE
#ifdef CONFIG_PLATFORM_EC_USB_PD_TBT_COMPAT_MODE
#define CONFIG_USB_PD_TBT_COMPAT_MODE
#endif

#undef CONFIG_USB_PD_USB4
#ifdef CONFIG_PLATFORM_EC_USB_PD_USB4
#define CONFIG_USB_PD_USB4
#endif

#undef CONFIG_USB_PD_DATA_RESET_MSG
#ifdef CONFIG_PLATFORM_EC_USB_PD_DATA_RESET_MSG
#define CONFIG_USB_PD_DATA_RESET_MSG
#endif

#undef CONFIG_USB_PD_FRS
#ifdef CONFIG_PLATFORM_EC_USB_PD_FRS
#define CONFIG_USB_PD_FRS
#endif

#undef CONFIG_USB_PD_FRS_TCPC
#ifdef CONFIG_PLATFORM_EC_USB_PD_FRS_TCPC
#define CONFIG_USB_PD_FRS_TCPC
#endif

#undef CONFIG_USB_PD_FRS_PPC
#ifdef CONFIG_PLATFORM_EC_USB_PD_FRS_PPC
#define CONFIG_USB_PD_FRS_PPC
#endif

#undef CONFIG_VSTORE
#undef VSTORE_SLOT_COUNT
#ifdef CONFIG_PLATFORM_EC_VSTORE
#define CONFIG_VSTORE
#define CONFIG_VSTORE_SLOT_COUNT CONFIG_PLATFORM_EC_VSTORE_SLOT_COUNT
#endif

#undef CONFIG_LID_SWITCH
#ifdef CONFIG_PLATFORM_EC_LID_SWITCH
#define CONFIG_LID_SWITCH
#endif

/* Integrated Sensor Hub: to set EC_FEATURE_ISH */
#undef CHIP_ISH
#ifdef CONFIG_SOC_FAMILY_INTEL_ISH
#define CHIP_ISH
#endif

/* motion sense */
#undef CONFIG_MOTIONSENSE
#ifdef CONFIG_PLATFORM_EC_MOTIONSENSE
#define CONFIG_MOTIONSENSE
#endif

#undef CONFIG_SENSOR_EC_RATE_FORCE_MODE
#ifdef CONFIG_PLATFORM_EC_SENSOR_EC_RATE_FORCE_MODE
#define CONFIG_SENSOR_EC_RATE_FORCE_MODE
#endif /* CONFIG_PLATFORM_EC_SENSOR_EC_RATE_FORCE_MODE */

#undef CONFIG_ACCEL_FIFO
#undef CONFIG_ACCEL_FIFO_SIZE
#undef CONFIG_ACCEL_FIFO_THRES
#ifdef CONFIG_PLATFORM_EC_ACCEL_FIFO
#define CONFIG_ACCEL_FIFO
#define CONFIG_ACCEL_FIFO_SIZE CONFIG_PLATFORM_EC_ACCEL_FIFO_SIZE
#define CONFIG_ACCEL_FIFO_THRES CONFIG_PLATFORM_EC_ACCEL_FIFO_THRES
#endif /* CONFIG_PLATFORM_EC_ACCEL_FIFO */

#undef CONFIG_BODY_DETECTION
#undef CONFIG_BODY_DETECTION_SENSOR
#undef CONFIG_BODY_DETECTION_MAX_WINDOW_SIZE
#undef CONFIG_BODY_DETECTION_VAR_THRESHOLD
#undef CONFIG_BODY_DETECTION_CONFIDENCE_DELTA
#undef CONFIG_BODY_DETECTION_VAR_NOISE_FACTOR
#undef CONFIG_BODY_DETECTION_ON_BODY_CON
#undef CONFIG_BODY_DETECTION_OFF_BODY_CON
#undef CONFIG_BODY_DETECTION_STATIONARY_DURATION
#undef CONFIG_BODY_DETECTION_NOTIFY_MODE_CHANGE
#undef CONFIG_BODY_DETECTION_ALWAYS_ENABLE_IN_S0
#ifdef CONFIG_PLATFORM_EC_BODY_DETECTION
#define CONFIG_BODY_DETECTION
#define CONFIG_BODY_DETECTION_SENSOR SENSOR_ID(DT_ALIAS(on_body_sensor))
#define CONFIG_BODY_DETECTION_MAX_WINDOW_SIZE \
	CONFIG_PLATFORM_EC_BODY_DETECTION_MAX_WINDOW_SIZE
#define CONFIG_BODY_DETECTION_VAR_THRESHOLD \
	CONFIG_PLATFORM_EC_BODY_DETECTION_VAR_THRESHOLD
#define CONFIG_BODY_DETECTION_CONFIDENCE_DELTA \
	CONFIG_PLATFORM_EC_BODY_DETECTION_CONFIDENCE_DELTA
#define CONFIG_BODY_DETECTION_VAR_NOISE_FACTOR \
	CONFIG_PLATFORM_EC_BODY_DETECTION_VAR_NOISE_FACTOR
#define CONFIG_BODY_DETECTION_ON_BODY_CON \
	CONFIG_PLATFORM_EC_BODY_DETECTION_ON_BODY_CON
#define CONFIG_BODY_DETECTION_OFF_BODY_CON \
	CONFIG_PLATFORM_EC_BODY_DETECTION_OFF_BODY_CON
#define CONFIG_BODY_DETECTION_STATIONARY_DURATION \
	CONFIG_PLATFORM_EC_BODY_DETECTION_STATIONARY_DURATION
#ifdef CONFIG_PLATFORM_EC_BODY_DETECTION_NOTIFY_MODE_CHANGE
#define CONFIG_BODY_DETECTION_NOTIFY_MODE_CHANGE
#endif /* CONFIG_PLATFORM_EC_BODY_DETECTION_NOTIFY_MODE_CHANGE */
#ifdef CONFIG_PLATFORM_EC_BODY_DETECTION_NOTIFY_MKBP
#define CONFIG_BODY_DETECTION_NOTIFY_MKBP
#endif /* CONFIG_PLATFORM_EC_BODY_DETECTION_NOTIFY_MKBP */
#ifdef CONFIG_PLATFORM_EC_BODY_DETECTION_ALWAYS_ENABLE_IN_S0
#define CONFIG_BODY_DETECTION_ALWAYS_ENABLE_IN_S0
#endif
#endif /* CONFIG_PLATFORM_EC_BODY_DETECTION */

#undef CONFIG_CMD_ACCELS
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_ACCELS
#define CONFIG_CMD_ACCELS
#endif

#undef CONFIG_CMD_ACCEL_INFO
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_ACCEL_INFO
#define CONFIG_CMD_ACCEL_INFO
#endif

#undef CONFIG_ACCEL_SPOOF_MODE
#ifdef CONFIG_PLATFORM_EC_ACCEL_SPOOF_MODE
#define CONFIG_ACCEL_SPOOF_MODE
#endif

#undef CONFIG_EC_MAX_SENSOR_FREQ_MILLIHZ
#ifdef CONFIG_PLATFORM_EC_MAX_SENSOR_FREQ_MILLIHZ
#define CONFIG_EC_MAX_SENSOR_FREQ_MILLIHZ \
	CONFIG_PLATFORM_EC_MAX_SENSOR_FREQ_MILLIHZ
#endif

#undef CONFIG_CMD_ACCEL_SPOOF
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_ACCEL_SPOOF
#define CONFIG_CMD_ACCEL_SPOOF
#endif

#undef CONFIG_GESTURE_DETECTION
#undef CONFIG_GESTURE_DETECTION_MASK
#ifdef CONFIG_PLATFORM_EC_GESTURE_DETECTION
#define CONFIG_GESTURE_DETECTION
#define CONFIG_GESTURE_DETECTION_MASK BIT(CONFIG_BODY_DETECTION_SENSOR)
#endif

#undef CONFIG_GESTURE_HOST_DETECTION
#ifdef CONFIG_PLATFORM_EC_GESTURE_HOST_DETECTION
#define CONFIG_GESTURE_HOST_DETECTION
#endif

#undef CONFIG_SENSOR_TIGHT_TIMESTAMPS
#ifdef CONFIG_PLATFORM_EC_SENSOR_TIGHT_TIMESTAMPS
#define CONFIG_SENSOR_TIGHT_TIMESTAMPS
#endif

#undef CONFIG_ALS
#undef CONFIG_ALS_COUNT
#if DT_NODE_HAS_PROP(SENSOR_INFO_NODE, als_sensors)
#define CONFIG_ALS
#define ALS_COUNT DT_PROP_LEN(SENSOR_INFO_NODE, als_sensors)
#else
#define ALS_COUNT 0
#endif

#undef CONFIG_DYNAMIC_MOTION_SENSOR_COUNT
#ifdef CONFIG_PLATFORM_EC_DYNAMIC_MOTION_SENSOR_COUNT
#define CONFIG_DYNAMIC_MOTION_SENSOR_COUNT
#endif

#undef CONFIG_LID_ANGLE
#ifdef CONFIG_PLATFORM_EC_LID_ANGLE
#define CONFIG_LID_ANGLE
#endif

#undef CONFIG_LID_ANGLE_UPDATE
#ifdef CONFIG_PLATFORM_EC_LID_ANGLE_UPDATE
#define CONFIG_LID_ANGLE_UPDATE
#endif

#undef CONFIG_TABLET_MODE
#ifdef CONFIG_PLATFORM_EC_TABLET_MODE
#define CONFIG_TABLET_MODE
#endif

#undef CONFIG_TABLET_MODE_SWITCH
#ifdef CONFIG_PLATFORM_EC_TABLET_MODE_SWITCH
#define CONFIG_TABLET_MODE_SWITCH
#endif

#undef CONFIG_GMR_TABLET_MODE
#ifdef CONFIG_PLATFORM_EC_GMR_TABLET_MODE
#define CONFIG_GMR_TABLET_MODE
#endif

#undef CONFIG_DPTF_MOTION_LID_NO_GMR_SENSOR
#ifdef CONFIG_PLATFORM_EC_DPTF_MOTION_LID_NO_GMR_SENSOR
#define CONFIG_DPTF_MOTION_LID_NO_GMR_SENSOR
#endif

#undef CONFIG_DPTF_DEBUG_PRINTS
#ifdef CONFIG_PLATFORM_EC_DPTF_PRINTS
#define CONFIG_DPTF_DEBUG_PRINTS
#endif

/* sensors */
#undef CONFIG_ACCELGYRO_BMI160
#ifdef CONFIG_PLATFORM_EC_ACCELGYRO_BMI160
#define CONFIG_ACCELGYRO_BMI160
#endif

#undef CONFIG_ACCELGYRO_BMI260
#ifdef CONFIG_PLATFORM_EC_ACCELGYRO_BMI260
#define CONFIG_ACCELGYRO_BMI260
#endif

#undef CONFIG_ACCELGYRO_BMI3XX
#ifdef CONFIG_PLATFORM_EC_ACCELGYRO_BMI3XX
#define CONFIG_ACCELGYRO_BMI3XX
#endif

#undef CONFIG_ACCEL_BMA255
#ifdef CONFIG_PLATFORM_EC_ACCEL_BMA255
#define CONFIG_ACCEL_BMA255
#endif

#undef CONFIG_ACCEL_BMA4XX
#ifdef CONFIG_PLATFORM_EC_ACCEL_BMA4XX
#define CONFIG_ACCEL_BMA4XX
#endif

#undef CONFIG_ACCEL_KX022
#ifdef CONFIG_PLATFORM_EC_ACCEL_KX022
#define CONFIG_ACCEL_KX022
#endif

#undef CONFIG_ACCEL_LIS2DS
#ifdef CONFIG_PLATFORM_EC_ACCEL_LIS2DS
#define CONFIG_ACCEL_LIS2DS
#endif

#undef CONFIG_ALS_TCS3400_EMULATED_IRQ_EVENT
#ifdef CONFIG_PLATFORM_EC_ALS_TCS3400_EMULATED_IRQ_EVENT
#define CONFIG_ALS_TCS3400_EMULATED_IRQ_EVENT
#endif

#undef CONFIG_ALS_TCS3400
#ifdef CONFIG_PLATFORM_EC_ALS_TCS3400
#define CONFIG_ALS_TCS3400
#endif

#undef CONFIG_ALS_VEML3328
#ifdef CONFIG_PLATFORM_EC_ALS_VEML3328
#define CONFIG_ALS_VEML3328
#endif

#undef CONFIG_ALS_CM32183
#ifdef CONFIG_PLATFORM_EC_ALS_CM32183
#define CONFIG_ALS_CM32183
#endif

#undef CONFIG_ACCELGYRO_ICM426XX
#ifdef CONFIG_PLATFORM_EC_ACCELGYRO_ICM426XX
#define CONFIG_ACCELGYRO_ICM426XX
#endif

#undef CONFIG_ACCELGYRO_ICM42607
#ifdef CONFIG_PLATFORM_EC_ACCELGYRO_ICM42607
#define CONFIG_ACCELGYRO_ICM42607
#endif

#undef CONFIG_ACCELGYRO_LSM6DSO
#ifdef CONFIG_PLATFORM_EC_ACCELGYRO_LSM6DSO
#define CONFIG_ACCELGYRO_LSM6DSO
#endif

#undef CONFIG_ACCELGYRO_LSM6DSM
#ifdef CONFIG_PLATFORM_EC_ACCELGYRO_LSM6DSM
#define CONFIG_ACCELGYRO_LSM6DSM
#endif

#undef CONFIG_MATH_UTIL
#ifdef CONFIG_PLATFORM_EC_MATH_UTIL
#define CONFIG_MATH_UTIL
#endif

#undef CONFIG_MAX695X_SEVEN_SEGMENT_DISPLAY
#ifdef CONFIG_PLATFORM_EC_MAX695X_SEVEN_SEGMENT_DISPLAY
#define CONFIG_MAX695X_SEVEN_SEGMENT_DISPLAY
#define PORT80_I2C_ADDR \
	DT_REG_ADDR(DT_COMPAT_GET_ANY_STATUS_OKAY(maxim_max695x))
BUILD_ASSERT((DT_NUM_INST_STATUS_OKAY(maxim_max695x)) == 1,
	     "Only one instance of maxim,max695x should be defined");
#endif

#undef CONFIG_CMD_SEVEN_SEG_DISPLAY
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_SEVEN_SEGMENT_DISPLAY
#define CONFIG_CMD_SEVEN_SEG_DISPLAY
#endif

#undef CONFIG_HOSTCMD_GET_UPTIME_INFO
#ifdef CONFIG_PLATFORM_EC_HOSTCMD_GET_UPTIME_INFO
#define CONFIG_HOSTCMD_GET_UPTIME_INFO
#endif

#undef CONFIG_CMD_AP_RESET_LOG
#ifdef CONFIG_PLATFORM_EC_AP_RESET_LOG
#define CONFIG_CMD_AP_RESET_LOG
#endif

#undef CONFIG_POWER_BUTTON
#ifdef CONFIG_PLATFORM_EC_POWER_BUTTON
#define CONFIG_POWER_BUTTON
#endif

#undef CONFIG_COMMON_PANIC_OUTPUT
#ifdef CONFIG_PLATFORM_EC_PANIC
#define CONFIG_COMMON_PANIC_OUTPUT
#endif

#undef CONFIG_DEBUG_ASSSERT_BRIEF
#ifdef CONFIG_PLATFORM_EC_DEBUG_ASSERT_BRIEF
#define CONFIG_DEBUG_ASSSERT_BRIEF
#endif

#undef CONFIG_PANIC_CONSOLE_OUTPUT
#ifdef CONFIG_PLATFORM_EC_PANIC_CONSOLE_OUTPUT
#define CONFIG_PANIC_CONSOLE_OUTPUT
#endif

#undef CONFIG_RNG
#ifdef CONFIG_PLATFORM_EC_RANDOM
#define CONFIG_RNG
#endif

#undef CONFIG_ROLLBACK
#ifdef CONFIG_PLATFORM_EC_ROLLBACK
#define CONFIG_ROLLBACK
#define CONFIG_ROLLBACK_OFF DT_REG_ADDR(DT_NODELABEL(rollback0))
#define CONFIG_ROLLBACK_SIZE                    \
	(DT_REG_SIZE(DT_NODELABEL(rollback0)) + \
	 DT_REG_SIZE(DT_NODELABEL(rollback1)))
#endif

#define CONFIG_ROLLBACK_SECRET_SIZE CONFIG_PLATFORM_EC_ROLLBACK_SECRET_SIZE

#undef CONFIG_ROLLBACK_UPDATE
#ifdef CONFIG_PLATFORM_EC_ROLLBACK_UPDATE
#define CONFIG_ROLLBACK_UPDATE
#endif

#undef CONFIG_ROLLBACK_VERSION
#ifdef CONFIG_PLATFORM_EC_ROLLBACK_VERSION
#define CONFIG_ROLLBACK_VERSION CONFIG_PLATFORM_EC_ROLLBACK_VERSION
#endif

#undef CONFIG_ROLLBACK_MPU_PROTECT
#ifdef CONFIG_PLATFORM_EC_ROLLBACK_MPU_PROTECT
#define CONFIG_ROLLBACK_MPU_PROTECT
#endif

#undef CONFIG_CMD_CRASH
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_CRASH
#define CONFIG_CMD_CRASH
#endif

#undef CONFIG_CMD_MEM
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_MEM
#define CONFIG_CMD_MEM
#endif

#undef CONFIG_CMD_MD
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_MD
#define CONFIG_CMD_MD
#endif

#undef CONFIG_CMD_RW
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_RW
#define CONFIG_CMD_RW
#endif

#undef CONFIG_RTC
#ifdef CONFIG_PLATFORM_EC_RTC
#define CONFIG_RTC
#endif

#undef CONFIG_CMD_RTC
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_RTC
#define CONFIG_CMD_RTC
#endif

#undef CONFIG_CMD_RTC_ALARM
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_RTC_ALARM
#define CONFIG_CMD_RTC_ALARM
#endif

#undef CONFIG_HOSTCMD_RTC
#ifdef CONFIG_PLATFORM_EC_HOSTCMD_RTC
#define CONFIG_HOSTCMD_RTC
#endif

#undef CONFIG_HOST_COMMAND_STATUS
#ifdef CONFIG_PLATFORM_EC_HOST_COMMAND_STATUS
#define CONFIG_HOST_COMMAND_STATUS
#endif

#undef CONFIG_SWITCH
#ifdef CONFIG_PLATFORM_EC_SWITCH
#define CONFIG_SWITCH
#endif

#undef CONFIG_LN9310
#ifdef CONFIG_PLATFORM_EC_SWITCHCAP_LN9310
#define CONFIG_LN9310
#endif

#undef CONFIG_BOARD_VERSION_CBI
#ifdef CONFIG_PLATFORM_EC_BOARD_VERSION_CBI
#define CONFIG_BOARD_VERSION_CBI
#endif

#undef CONFIG_BOARD_VERSION_GPIO
#ifdef CONFIG_PLATFORM_EC_BOARD_VERSION_GPIO
#define CONFIG_BOARD_VERSION_GPIO
#endif

#undef CONFIG_CBI_EEPROM
#ifdef CONFIG_PLATFORM_EC_CBI_EEPROM
#define CONFIG_CBI_EEPROM
#define I2C_ADDR_EEPROM_FLAGS DT_REG_ADDR(DT_NODELABEL(cbi_eeprom))
#endif

#undef CONFIG_EEPROM_CBI_WP
#ifdef CONFIG_PLATFORM_EC_EEPROM_CBI_WP
#define CONFIG_EEPROM_CBI_WP
#endif

#undef CONFIG_CBI_GPIO
#ifdef CONFIG_PLATFORM_EC_CBI_GPIO
#define CONFIG_CBI_GPIO
#endif

#undef CONFIG_CBI_FLASH
#ifdef CONFIG_PLATFORM_EC_CBI_FLASH
#define CONFIG_CBI_FLASH
#endif

#undef CONFIG_VBOOT_HASH
#ifdef CONFIG_PLATFORM_EC_VBOOT_HASH
#define CONFIG_VBOOT_HASH
#endif

#undef CONFIG_SHA256_SW
#ifdef CONFIG_PLATFORM_EC_SHA256_SW
#define CONFIG_SHA256_SW
#endif

#undef CONFIG_SHA256_HW_ACCELERATE
#ifdef CONFIG_PLATFORM_EC_SHA256_HW_ACCELERATE
#define CONFIG_SHA256_HW_ACCELERATE
#endif

#undef CONFIG_SHA256_UNROLLED
#ifdef CONFIG_PLATFORM_EC_SHA256_UNROLLED
#define CONFIG_SHA256_UNROLLED
#endif

#undef CONFIG_RO_HDR_MEM_OFF
#ifdef CONFIG_PLATFORM_EC_RO_HEADER_OFFSET
#define CONFIG_RO_HDR_MEM_OFF CONFIG_PLATFORM_EC_RO_HEADER_OFFSET
#else
#define CONFIG_RO_HDR_MEM_OFF 0
#endif

#undef CONFIG_RO_HDR_SIZE
#ifdef CONFIG_PLATFORM_EC_RO_HEADER_SIZE
#define CONFIG_RO_HDR_SIZE CONFIG_PLATFORM_EC_RO_HEADER_SIZE
#else
#define CONFIG_RO_HDR_SIZE 0
#endif

#undef CONFIG_SYSTEM_UNLOCKED
#ifdef CONFIG_PLATFORM_EC_SYSTEM_UNLOCKED
#define CONFIG_SYSTEM_UNLOCKED
#endif

#undef CONFIG_CMD_GPIO_EXTENDED
#ifdef CONFIG_PLATFORM_EC_CMD_GPIO_EXTENDED
#define CONFIG_CMD_GPIO_EXTENDED
#endif

#undef CONFIG_BYPASS_CBI_EEPROM_WP_CHECK
#ifdef CONFIG_PLATFORM_EC_BYPASS_CBI_EEPROM_WP_CHECK
#define CONFIG_BYPASS_CBI_EEPROM_WP_CHECK
#endif

#undef CONFIG_SPI_FLASH_REGS
#ifdef CONFIG_PLATFORM_EC_SPI_FLASH_REGS
#define CONFIG_SPI_FLASH_REGS
#endif

#undef CONFIG_CMD_CHARGEN
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_CHARGEN
#define CONFIG_CMD_CHARGEN
#endif

#undef CONFIG_DEBUG_ASSERT
#ifdef CONFIG_PLATFORM_EC_DEBUG_ASSERT
#define CONFIG_DEBUG_ASSERT
#endif

#undef CONFIG_DEBUG_ASSERT_BRIEF
#ifdef CONFIG_PLATFORM_EC_DEBUG_ASSERT_BRIEF
#define CONFIG_DEBUG_ASSERT_BRIEF
#endif

#undef CONFIG_DEBUG_ASSERT_REBOOTS
#ifdef CONFIG_PLATFORM_EC_DEBUG_ASSERT_REBOOTS
#define CONFIG_DEBUG_ASSERT_REBOOTS
#endif

#undef CONFIG_CMD_SYSINFO
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_SYSINFO
#define CONFIG_CMD_SYSINFO
#endif

#undef CONFIG_CMD_SCRATCHPAD
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_SCRATCHPAD
#define CONFIG_CMD_SCRATCHPAD
#endif

#undef CONFIG_CMD_SYSJUMP
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_SYSJUMP
#define CONFIG_CMD_SYSJUMP
#endif

#undef CONFIG_WATCHDOG_PERIOD_MS
#ifdef CONFIG_PLATFORM_EC_WATCHDOG_PERIOD_MS
#define CONFIG_WATCHDOG_PERIOD_MS CONFIG_PLATFORM_EC_WATCHDOG_PERIOD_MS
#endif

#undef CONFIG_WATCHDOG_WARNING_LEADING_TIME_MS
#if defined(CONFIG_PLATFORM_EC_WATCHDOG_WARNING_LEADING_TIME_MS) || \
	defined(CONFIG_WDT_NPCX_DELAY_CYCLES) ||                    \
	defined(CONFIG_WDT_ITE_WARNING_LEADING_TIME_MS)
/*
 * Note:
 * NPCX wdt driver uses CONFIG_WDT_NPCX_DELAY_CYCLES to set the leading
 * time of the watchdog warning timer.
 * IT8XXX2 WDT driver uses CONFIG_WDT_ITE_WARNING_LEADING_TIME_MS period
 * between watchdog warning and reset.
 */
#ifdef CONFIG_WDT_NPCX_DELAY_CYCLES
#define CONFIG_WATCHDOG_WARNING_LEADING_TIME_MS \
	(CONFIG_WDT_NPCX_DELAY_CYCLES * 31)
#elif CONFIG_WDT_ITE_WARNING_LEADING_TIME_MS
#define CONFIG_WATCHDOG_WARNING_LEADING_TIME_MS \
	CONFIG_WDT_ITE_WARNING_LEADING_TIME_MS
#else
#define CONFIG_WATCHDOG_WARNING_LEADING_TIME_MS \
	CONFIG_PLATFORM_EC_WATCHDOG_WARNING_LEADING_TIME_MS
#endif
#endif

#undef CONFIG_VBOOT_EFS
#undef CONFIG_VBOOT_EFS2
#ifdef CONFIG_PLATFORM_EC_VBOOT_EFS2
#define CONFIG_VBOOT_EFS2
#endif

#undef CONFIG_USB_PD_TCPC_VCONN
#ifdef CONFIG_PLATFORM_EC_USB_PD_TCPC_VCONN
#define CONFIG_USB_PD_TCPC_VCONN
#endif

#undef CONFIG_DPTF
#ifdef CONFIG_PLATFORM_EC_DPTF
#define CONFIG_DPTF
#endif

#undef CONFIG_CHARGER_BQ25710
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710
#define CONFIG_CHARGER_BQ25710
#endif

#undef CONFIG_CHARGER_BQ25720
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25720
#define CONFIG_CHARGER_BQ25720
#endif

#undef CONFIG_CHARGER_BQ257X0_ILIM2_VTH_CUSTOM
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ257X0_ILIM2_VTH_CUSTOM
#define CONFIG_CHARGER_BQ257X0_ILIM2_VTH_CUSTOM
#endif

#undef CONFIG_CHARGER_BQ257X0_ILIM2_VTH
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ257X0_ILIM2_VTH
#define CONFIG_CHARGER_BQ257X0_ILIM2_VTH \
	CONFIG_PLATFORM_EC_CHARGER_BQ257X0_ILIM2_VTH
#endif

#undef CONFIG_CHARGER_BQ25720_VSYS_TH2_CUSTOM
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25720_VSYS_TH2_CUSTOM
#define CONFIG_CHARGER_BQ25720_VSYS_TH2_CUSTOM
#endif

#undef CONFIG_CHARGER_BQ25720_VSYS_TH2_DV
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25720_VSYS_TH2_DV
#define CONFIG_CHARGER_BQ25720_VSYS_TH2_DV \
	CONFIG_PLATFORM_EC_CHARGER_BQ25720_VSYS_TH2_DV
#endif

#undef CONFIG_CHARGER_BQ25720_VSYS_UVP_CUSTOM
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25720_VSYS_UVP_CUSTOM
#define CONFIG_CHARGER_BQ25720_VSYS_UVP_CUSTOM
#endif

#undef CONFIG_CHARGER_BQ25720_VSYS_UVP
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25720_VSYS_UVP
#define CONFIG_CHARGER_BQ25720_VSYS_UVP \
	CONFIG_PLATFORM_EC_CHARGER_BQ25720_VSYS_UVP
#endif

#undef CONFIG_CHARGER_BQ25720_IDCHG_DEG2_CUSTOM
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25720_IDCHG_DEG2_CUSTOM
#define CONFIG_CHARGER_BQ25720_IDCHG_DEG2_CUSTOM
#endif

#undef CONFIG_CHARGER_BQ25720_IDCHG_DEG2
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25720_IDCHG_DEG2
#define CONFIG_CHARGER_BQ25720_IDCHG_DEG2 \
	CONFIG_PLATFORM_EC_CHARGER_BQ25720_IDCHG_DEG2
#endif

#undef CONFIG_CHARGER_BQ25720_IDCHG_TH2_CUSTOM
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25720_IDCHG_TH2_CUSTOM
#define CONFIG_CHARGER_BQ25720_IDCHG_TH2_CUSTOM
#endif

#undef CONFIG_CHARGER_BQ25720_IDCHG_TH2
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25720_IDCHG_TH2
#define CONFIG_CHARGER_BQ25720_IDCHG_TH2 \
	CONFIG_PLATFORM_EC_CHARGER_BQ25720_IDCHG_TH2
#endif

#undef CONFIG_CHARGER_BQ25710_VSYS_MIN_VOLTAGE_CUSTOM
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_VSYS_MIN_VOLTAGE_CUSTOM
#define CONFIG_CHARGER_BQ25710_VSYS_MIN_VOLTAGE_CUSTOM
#endif

#undef CONFIG_CHARGER_BQ25710_VSYS_MIN_VOLTAGE_MV
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_VSYS_MIN_VOLTAGE_MV
#define CONFIG_CHARGER_BQ25710_VSYS_MIN_VOLTAGE_MV \
	CONFIG_PLATFORM_EC_CHARGER_BQ25710_VSYS_MIN_VOLTAGE_MV
#endif

#undef CONFIG_HIBERNATE_PSL
#ifdef CONFIG_PLATFORM_EC_HIBERNATE_PSL
#define CONFIG_HIBERNATE_PSL
#endif

#ifdef CONFIG_PLATFORM_EC_HIBERNATE_DELAY_SEC
#undef CONFIG_HIBERNATE_DELAY_SEC
#define CONFIG_HIBERNATE_DELAY_SEC CONFIG_PLATFORM_EC_HIBERNATE_DELAY_SEC
#endif

#undef CONFIG_HIBERNATE
#ifdef CONFIG_PLATFORM_EC_HIBERNATE
#define CONFIG_HIBERNATE
#endif

#undef CONFIG_BATTERY_DEVICE_CHEMISTRY
#ifdef CONFIG_PLATFORM_EC_USE_BATTERY_DEVICE_CHEMISTRY
#define CONFIG_BATTERY_DEVICE_CHEMISTRY \
	CONFIG_PLATFORM_EC_BATTERY_DEVICE_CHEMISTRY
#endif

#undef CONFIG_CHARGER_BQ25710_PSYS_SENSING
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_PSYS_SENSING
#define CONFIG_CHARGER_BQ25710_PSYS_SENSING
#endif

#undef CONFIG_CHARGER_BQ25710_CMP_REF_1P2
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_CMP_REF_1P2
#define CONFIG_CHARGER_BQ25710_CMP_REF_1P2
#endif

#undef CONFIG_CHARGER_BQ25710_CMP_POL_EXTERNAL
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_CMP_POL_EXTERNAL
#define CONFIG_CHARGER_BQ25710_CMP_POL_EXTERNAL
#endif

#undef CONFIG_CHARGER_BQ25710_PKPWR_TOVLD_DEG_CUSTOM
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_PKPWR_TOVLD_DEG_CUSTOM
#define CONFIG_CHARGER_BQ25710_PKPWR_TOVLD_DEG_CUSTOM
#endif

#undef CONFIG_CHARGER_BQ25710_PKPWR_TOVLD_DEG
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_PKPWR_TOVLD_DEG
#define CONFIG_CHARGER_BQ25710_PKPWR_TOVLD_DEG \
	CONFIG_PLATFORM_EC_CHARGER_BQ25710_PKPWR_TOVLD_DEG
#endif

#undef CONFIG_CHARGER_BQ25710_EN_ACOC
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_EN_ACOC
#define CONFIG_CHARGER_BQ25710_EN_ACOC
#endif

#undef CONFIG_CHARGER_BQ25710_ACOC_VTH_1P33
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_ACOC_VTH_1P33
#define CONFIG_CHARGER_BQ25710_ACOC_VTH_1P33
#endif

#undef CONFIG_CHARGER_BQ25710_BATOC_VTH_MINIMUM
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_BATOC_VTH_MINIMUM
#define CONFIG_CHARGER_BQ25710_BATOC_VTH_MINIMUM
#endif

#undef CONFIG_CHARGER_BQ25710_SENSE_RESISTOR
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_SENSE_RESISTOR
#define CONFIG_CHARGER_BQ25710_SENSE_RESISTOR \
	CONFIG_PLATFORM_EC_CHARGER_BQ25710_SENSE_RESISTOR
#endif

#undef CONFIG_CHARGER_BQ25710_SENSE_RESISTOR_AC
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_SENSE_RESISTOR_AC
#define CONFIG_CHARGER_BQ25710_SENSE_RESISTOR_AC \
	CONFIG_PLATFORM_EC_CHARGER_BQ25710_SENSE_RESISTOR_AC
#endif

#undef CONFIG_CHARGER_BQ25710_PP_INOM
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_PP_INOM
#define CONFIG_CHARGER_BQ25710_PP_INOM
#endif

#undef CONFIG_CHARGER_BQ25710_PP_BATPRES
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_PP_BATPRES
#define CONFIG_CHARGER_BQ25710_PP_BATPRES
#endif

#undef CONFIG_CHARGER_BQ25710_PP_ACOK
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_PP_ACOK
#define CONFIG_CHARGER_BQ25710_PP_ACOK
#endif

#undef CONFIG_CHARGER_BQ25710_PP_COMP
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25710_PP_COMP
#define CONFIG_CHARGER_BQ25710_PP_COMP
#endif

#undef CONFIG_CHARGER_BQ25720_PP_IDCHG2
#ifdef CONFIG_PLATFORM_EC_CHARGER_BQ25720_PP_IDCHG2
#define CONFIG_CHARGER_BQ25720_PP_IDCHG2
#endif

#undef CONFIG_CHARGER_DISCHARGE_ON_AC
#ifdef CONFIG_PLATFORM_EC_CHARGER_DISCHARGE_ON_AC
#define CONFIG_CHARGER_DISCHARGE_ON_AC
#endif

#undef CONFIG_CHARGER_DISCHARGE_ON_AC_CUSTOM
#ifdef CONFIG_PLATFORM_EC_CHARGER_DISCHARGE_ON_AC_CUSTOM
#define CONFIG_CHARGER_DISCHARGE_ON_AC_CUSTOM
#endif

#undef CONFIG_CHARGER_SENSE_RESISTOR
#ifdef CONFIG_PLATFORM_EC_CHARGER_SENSE_RESISTOR
#define CONFIG_CHARGER_SENSE_RESISTOR CONFIG_PLATFORM_EC_CHARGER_SENSE_RESISTOR
#endif

#undef CONFIG_CHARGER_SENSE_RESISTOR_AC
#ifdef CONFIG_PLATFORM_EC_CHARGER_SENSE_RESISTOR_AC
#define CONFIG_CHARGER_SENSE_RESISTOR_AC \
	CONFIG_PLATFORM_EC_CHARGER_SENSE_RESISTOR_AC
#endif

#undef CONFIG_CHARGER_PROFILE_OVERRIDE
#ifdef CONFIG_PLATFORM_EC_CHARGER_PROFILE_OVERRIDE
#define CONFIG_CHARGER_PROFILE_OVERRIDE
#endif

#undef CONFIG_CHARGER_PSYS
#ifdef CONFIG_PLATFORM_EC_CHARGER_PSYS
#define CONFIG_CHARGER_PSYS
#endif

#undef CONFIG_CHARGER_PSYS_READ
#ifdef CONFIG_PLATFORM_EC_CHARGER_PSYS_READ
#define CONFIG_CHARGER_PSYS_READ
#endif

#undef CONFIG_CMD_CHARGER_ADC_AMON_BMON
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_CHARGER_ADC_AMON_BMON
#define CONFIG_CMD_CHARGER_ADC_AMON_BMON
#endif

#undef CONFIG_USB_PD_PULLUP
#define CONFIG_USB_PD_PULLUP CONFIG_PLATFORM_EC_USB_PD_PULLUP

#undef CONFIG_USB_PD_ONLY_FIXED_PDOS
#ifdef CONFIG_PLATFORM_EC_USB_PD_ONLY_FIXED_PDOS
#define CONFIG_USB_PD_ONLY_FIXED_PDOS
#endif

#undef CONFIG_MP2964
#ifdef CONFIG_PLATFORM_EC_MP2964
#define CONFIG_MP2964
#define I2C_ADDR_MP2964_FLAGS \
	DT_REG_ADDR(DT_COMPAT_GET_ANY_STATUS_OKAY(mps_mp2964))
BUILD_ASSERT((DT_NUM_INST_STATUS_OKAY(mps_mp2964)) == 1,
	     "Only one instance of mps,mp2964 should be defined");
#endif

#undef CONFIG_ACCELGYRO_ICM_COMM_SPI
#ifdef CONFIG_PLATFORM_EC_ACCELGYRO_ICM_COMM_SPI
#define CONFIG_ACCELGYRO_ICM_COMM_SPI
#endif

#undef CONFIG_ACCELGYRO_ICM_COMM_I2C
#ifdef CONFIG_PLATFORM_EC_ACCELGYRO_ICM_COMM_I2C
#define CONFIG_ACCELGYRO_ICM_COMM_I2C
#endif

#undef CONFIG_ACCELGYRO_BMI_COMM_SPI
#ifdef CONFIG_PLATFORM_EC_ACCELGYRO_BMI_COMM_SPI
#define CONFIG_ACCELGYRO_BMI_COMM_SPI
#endif

#undef CONFIG_ACCELGYRO_BMI_COMM_I2C
#ifdef CONFIG_PLATFORM_EC_ACCELGYRO_BMI_COMM_I2C
#define CONFIG_ACCELGYRO_BMI_COMM_I2C
#endif

#undef CONFIG_CMD_SLEEPMASK
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_SLEEPMASK
#define CONFIG_CMD_SLEEPMASK
#endif

#undef CONFIG_CMD_SLEEPMASK_SET
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_SLEEPMASK_SET
#define CONFIG_CMD_SLEEPMASK_SET
#endif

#undef CONFIG_LOW_POWER_IDLE
#ifdef CONFIG_PLATFORM_EC_LOW_POWER_IDLE
#define CONFIG_LOW_POWER_IDLE
#endif

#undef CONFIG_LOW_POWER_S0
#ifdef CONFIG_PLATFORM_EC_LOW_POWER_S0
#define CONFIG_LOW_POWER_S0
#endif

#undef CONFIG_POWER_COMMON
#ifdef CONFIG_PLATFORM_EC_POWER_COMMON
#define CONFIG_POWER_COMMON
#endif

#undef CONFIG_PORT80_4_BYTE
#ifdef CONFIG_PLATFORM_EC_PORT80_4_BYTE
#define CONFIG_PORT80_4_BYTE
#endif

#undef CONFIG_PORT80_QUIET
#ifdef CONFIG_PLATFORM_EC_PORT80_QUIET
#define CONFIG_PORT80_QUIET
#endif

#undef CONFIG_ASSERT_CCD_MODE_ON_DTS_CONNECT
#ifdef CONFIG_PLATFORM_EC_ASSERT_CCD_MODE_ON_DTS_CONNECT
#define CONFIG_ASSERT_CCD_MODE_ON_DTS_CONNECT
#endif

#undef CONFIG_CCD_USBC_PORT_NUMBER
#ifdef CONFIG_PLATFORM_EC_CCD_USBC_PORT_NUMBER
#define CONFIG_CCD_USBC_PORT_NUMBER CONFIG_PLATFORM_EC_CCD_USBC_PORT_NUMBER
#endif

#undef CONFIG_ACCEL_LIS2DW12
#ifdef CONFIG_PLATFORM_EC_ACCEL_LIS2DW12
#define CONFIG_ACCEL_LIS2DW12
#endif

#undef CONFIG_CONSOLE_CHANNEL
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CHANNEL
#define CONFIG_CONSOLE_CHANNEL
#endif

#undef CONFIG_PRINTF_LONG_IS_32BITS
#ifdef CONFIG_PLATFORM_EC_PRINTF_LONG_IS_32BITS
#define CONFIG_PRINTF_LONG_IS_32BITS
#endif

#undef CONFIG_USB_PD_DP_HPD_GPIO
#ifdef CONFIG_PLATFORM_EC_USB_PD_DP_HPD_GPIO
#define CONFIG_USB_PD_DP_HPD_GPIO
#endif

#undef CONFIG_USB_PD_DP_HPD_GPIO_CUSTOM
#ifdef CONFIG_PLATFORM_EC_USB_PD_DP_HPD_GPIO_CUSTOM
#define CONFIG_USB_PD_DP_HPD_GPIO_CUSTOM
#endif

#undef CONFIG_USB_PD_DP_HPD_GPIO_IRQ_ACCURATE
#ifdef CONFIG_PLATFORM_EC_USB_PD_DP_HPD_GPIO_IRQ_ACCURATE
#define CONFIG_USB_PD_DP_HPD_GPIO_IRQ_ACCURATE
#endif

#undef CONSOLE_CMD_MFALLOW
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_MFALLOW
#define CONSOLE_CMD_MFALLOW
#endif

#undef CONFIG_TEMP_SENSOR_FIRST_READ_DELAY_MS
#ifdef CONFIG_PLATFORM_EC_TEMP_SENSOR_FIRST_READ_DELAY
#define CONFIG_TEMP_SENSOR_FIRST_READ_DELAY_MS \
	CONFIG_PLATFORM_EC_TEMP_SENSOR_FIRST_READ_DELAY_MS
#endif

#undef CONFIG_CMD_S5_TIMEOUT
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_S5_TIMEOUT
#define CONFIG_CMD_S5_TIMEOUT
#endif

#undef CONFIG_CMD_BATTERY_CONFIG
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_BATTERY_CONFIG
#define CONFIG_CMD_BATTERY_CONFIG
#endif

#undef CONFIG_FW_RESET_VECTOR
#ifdef CONFIG_PLATFORM_EC_FW_RESET_VECTOR
#define CONFIG_FW_RESET_VECTOR
#endif

#undef CONFIG_HOSTCMD_DEBUG_MODE
#ifdef CONFIG_PLATFORM_EC_HOSTCMD_DEBUG_MODE
#define CONFIG_HOSTCMD_DEBUG_MODE CONFIG_PLATFORM_EC_HOSTCMD_DEBUG_MODE
#endif

#undef CONFIG_AMD_SB_RMI
#ifdef CONFIG_PLATFORM_EC_AMD_SB_RMI
#define CONFIG_AMD_SB_RMI
#endif

#undef CONFIG_AMD_STT
#ifdef CONFIG_PLATFORM_EC_AMD_STT
#define CONFIG_AMD_STT
#endif

#ifdef CONFIG_PLATFORM_EC_IOEX_CROS_DRV
#define CONFIG_IO_EXPANDER_SUPPORT_GET_PORT
#endif

#undef CONFIG_USB_PD_REQUIRE_AP_MODE_ENTRY
#ifdef CONFIG_PLATFORM_EC_USB_PD_REQUIRE_AP_MODE_ENTRY
#define CONFIG_USB_PD_REQUIRE_AP_MODE_ENTRY
#endif

#undef CONFIG_USB_PD_VDM_AP_CONTROL
#ifdef CONFIG_PLATFORM_EC_USB_PD_VDM_AP_CONTROL
#define CONFIG_USB_PD_VDM_AP_CONTROL
#endif

#undef CONFIG_USB_PD_CLEAR_HARD_RESET_STATUS
#ifdef CONFIG_PLATFORM_EC_USB_PD_CLEAR_HARD_RESET_STATUS
#define CONFIG_USB_PD_CLEAR_HARD_RESET_STATUS
#endif

#undef CONFIG_DEDICATED_CHARGE_PORT_COUNT
#ifdef CONFIG_PLATFORM_EC_DEDICATED_CHARGE_PORT
#define CONFIG_DEDICATED_CHARGE_PORT_COUNT 1
#define DEDICATED_CHARGE_PORT CONFIG_USB_PD_PORT_MAX_COUNT
#else
#define CONFIG_DEDICATED_CHARGE_PORT_COUNT 0
#endif

#undef CONFIG_IO_EXPANDER_CCGXXF
#ifdef CONFIG_PLATFORM_EC_IOEX_CCGXXF
#define CONFIG_IO_EXPANDER_CCGXXF
#endif

#undef CONFIG_PERIPHERAL_CHARGER
#ifdef CONFIG_PLATFORM_EC_PERIPHERAL_CHARGER
#define CONFIG_PERIPHERAL_CHARGER
#endif

#undef CONFIG_CPS8100
#ifdef CONFIG_PLATFORM_EC_CPS8100
#define CONFIG_CPS8100
#endif

#undef CONFIG_SYSTEM_SAFE_MODE
#ifdef CONFIG_PLATFORM_EC_SYSTEM_SAFE_MODE
#define CONFIG_SYSTEM_SAFE_MODE
#endif

#undef CONFIG_SYSTEM_SAFE_MODE_TIMEOUT_MSEC
#ifdef CONFIG_PLATFORM_EC_SYSTEM_SAFE_MODE_TIMEOUT_MSEC
#define CONFIG_SYSTEM_SAFE_MODE_TIMEOUT_MSEC \
	CONFIG_PLATFORM_EC_SYSTEM_SAFE_MODE_TIMEOUT_MSEC
#endif

#undef CONFIG_SYSTEM_SAFE_MODE_PRINT_STACK
#ifdef CONFIG_PLATFORM_EC_SYSTEM_SAFE_MODE_PRINT_STACK
#define CONFIG_SYSTEM_SAFE_MODE_PRINT_STACK
#endif

#undef CONFIG_HOST_COMMAND_MEMORY_DUMP
#ifdef CONFIG_PLATFORM_EC_HOST_COMMAND_MEMORY_DUMP
#define CONFIG_HOST_COMMAND_MEMORY_DUMP
#endif

#undef CONFIG_BATT_HOST_FULL_FACTOR
#ifdef CONFIG_PLATFORM_EC_BATT_HOST_FULL_FACTOR
#define CONFIG_BATT_HOST_FULL_FACTOR CONFIG_PLATFORM_EC_BATT_HOST_FULL_FACTOR
#endif

#undef CONFIG_TOUCHPAD
#ifdef CONFIG_PLATFORM_EC_TOUCHPAD
#define CONFIG_TOUCHPAD
#endif

#undef CONFIG_DETACHABLE_BASE
#ifdef CONFIG_PLATFORM_EC_DETACHABLE_BASE
#define CONFIG_DETACHABLE_BASE
#define CONFIG_BASE_ATTACHED_SWITCH
#endif

#undef CONFIG_BASE_ATTACHED_SWITCH
#ifdef CONFIG_PLATFORM_EC_BASE_ATTACHED_SWITCH
#define CONFIG_BASE_ATTACHED_SWITCH
#endif

#undef CONFIG_RWSIG
#ifdef CONFIG_PLATFORM_EC_RWSIG_VERIFY
#define CONFIG_RWSIG

#ifdef CONFIG_PLATFORM_EC_RWSIG_TYPE_RWSIG
#define CONFIG_RWSIG_TYPE_RWSIG
#endif

#endif /* CONFIG_PLATFORM_EC_RWSIG */

#undef CONFIG_RO_PUBKEY_STORAGE_OFF
#ifdef CONFIG_PLATFORM_EC_RO_PUBKEY_STORAGE_OFF
#define CONFIG_RO_PUBKEY_STORAGE_OFF CONFIG_PLATFORM_EC_RO_PUBKEY_STORAGE_OFF
#endif /* CONFIG_RO_PUBKEY_STORAGE_OFF */

#undef CONFIG_RSA
#ifdef CONFIG_PLATFORM_EC_RSA
#define CONFIG_RSA
#define CONFIG_RSA_KEY_SIZE CONFIG_PLATFORM_EC_RSA_KEY_SIZE

#ifdef CONFIG_PLATFORM_EC_RSA_EXPONENT_3
#define CONFIG_RSA_EXPONENT_3
#endif
#endif /* CONFIG_PLATFORM_EC_RSA */

#undef CONFIG_CEC
#ifdef CONFIG_PLATFORM_EC_CEC
#define CONFIG_CEC
#endif

#undef CONFIG_CEC_DEBUG
#ifdef CONFIG_PLATFORM_EC_CEC_DEBUG
#define CONFIG_CEC_DEBUG
#endif

#undef CONFIG_CEC_BITBANG
#ifdef CONFIG_PLATFORM_EC_CEC_BITBANG
#define CONFIG_CEC_BITBANG
#endif

#undef CONFIG_BATTERY_CUTOFF_TIMEOUT_MSEC
#ifdef CONFIG_PLATFORM_EC_BATTERY_CUTOFF_TIMEOUT_MSEC
#define CONFIG_BATTERY_CUTOFF_TIMEOUT_MSEC \
	CONFIG_PLATFORM_EC_BATTERY_CUTOFF_TIMEOUT_MSEC
#endif

#undef CONFIG_CEC_IT83XX
#ifdef CONFIG_PLATFORM_EC_CEC_IT83XX
#define CONFIG_CEC_IT83XX
#endif

#undef CONFIG_CMD_CBI
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_CBI
#define CONFIG_CMD_CBI
#endif

#undef CONFIG_CMD_MMAPINFO
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_MMAPINFO
#define CONFIG_CMD_MMAPINFO
#endif

#undef CONFIG_CMD_TYPEC
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_TYPEC
#define CONFIG_CMD_TYPEC
#endif

#undef CONFIG_CMD_HASH
#ifdef CONFIG_PLATFORM_EC_CONSOLE_CMD_HASH
#define CONFIG_CMD_HASH
#endif

#undef CONFIG_USB_UPDATE
#ifdef CONFIG_PLATFORM_EC_USB_UPDATE
#define CONFIG_USB_UPDATE
#endif

#undef CONFIG_TOUCHPAD_VIRTUAL_SIZE
#ifdef CONFIG_PLATFORM_EC_TOUCHPAD_VIRTUAL_SIZE
#define CONFIG_TOUCHPAD_VIRTUAL_SIZE CONFIG_PLATFORM_EC_TOUCHPAD_VIRTUAL_SIZE
#endif

#undef CONFIG_TOUCHPAD_VIRTUAL_OFF
#ifdef CONFIG_PLATFORM_EC_TOUCHPAD_VIRTUAL_OFF
#define CONFIG_TOUCHPAD_VIRTUAL_OFF CONFIG_PLATFORM_EC_TOUCHPAD_VIRTUAL_OFF
#endif

#undef CONFIG_USB_PAIRING
#ifdef CONFIG_PLATFORM_EC_USB_PAIRING
#define CONFIG_USB_PAIRING
#endif

#undef CONFIG_TOUCHPAD_HASH_FW
#ifdef CONFIG_PLATFORM_EC_TOUCHPAD_HASH_FW
#define CONFIG_TOUCHPAD_HASH_FW
#endif

#undef CONFIG_UPDATE_PDU_SIZE
#ifdef CONFIG_PLATFORM_EC_UPDATE_PDU_SIZE
#define CONFIG_UPDATE_PDU_SIZE CONFIG_PLATFORM_EC_UPDATE_PDU_SIZE
#endif

#undef CONFIG_AP_HANG_DETECT
#ifdef CONFIG_PLATFORM_EC_AP_HANG_DETECT
#define CONFIG_AP_HANG_DETECT
#endif

#undef CONFIG_CMD_FPSENSOR_DEBUG
#ifdef CONFIG_FINGERPRINT_SHELL
#define CONFIG_CMD_FPSENSOR_DEBUG
#endif

#undef CONFIG_ISL9238C_INPUT_VOLTAGE_MV
#ifdef CONFIG_PLATFORM_EC_ISL9238C_INPUT_VOLTAGE_MV
#define CONFIG_ISL9238C_INPUT_VOLTAGE_MV \
	CONFIG_PLATFORM_EC_ISL9238C_INPUT_VOLTAGE_MV
#endif

#undef CONFIG_FLASH_PROTECT_RW
#ifdef CONFIG_PLATFORM_EC_FLASH_PROTECT_RW
#define CONFIG_FLASH_PROTECT_RW
#endif

#undef CONFIG_FLASH_PROTECT_NEXT_BOOT
#ifdef CONFIG_PLATFORM_EC_FLASH_PROTECT_NEXT_BOOT
#define CONFIG_FLASH_PROTECT_NEXT_BOOT
#endif

#undef CONFIG_FEATURE_FINCH
#ifdef CONFIG_PLATFORM_EC_FEATURE_FINCH
#define CONFIG_FEATURE_FINCH
#endif

#endif /* __CROS_EC_CONFIG_CHIP_H */
