/* Copyright 2021 The ChromiumOS Authors
 * Use of this source code is governed by a BSD-style license that can be
 * found in the LICENSE file.
 */

#ifdef __REQUIRE_ZEPHYR_GPIOS__
#undef __REQUIRE_ZEPHYR_GPIOS__
#endif

#include "gpio.h"
#include "util.h"

#include <zephyr/devicetree.h>

#define CONVERT_NUMERAL_SYSTEM_EVAL(system, bits, nbits) \
	system##_from_bits(bits, nbits)
#define CONVERT_NUMERAL_SYSTEM(system, bits, nbits) \
	CONVERT_NUMERAL_SYSTEM_EVAL(system, bits, nbits)

/* TODO: b/218904113: Convert to using Zephyr GPIOs */
#define READ_PIN_FROM_PHANDLE(node_id, prop, idx) \
	gpio_get_ternary(GPIO_SIGNAL(DT_PHANDLE_BY_IDX(node_id, prop, idx))),

#define SKU_GPIO_ID_NODE DT_NODELABEL(gpio_id_sku)
#if DT_NODE_HAS_STATUS(SKU_GPIO_ID_NODE, okay)

__override uint32_t board_get_sku_id(void)
{
	static uint32_t sku_id = (uint32_t)-1;

	if (sku_id == (uint32_t)-1) {
		int bits[] = { DT_FOREACH_PROP_ELEM(SKU_GPIO_ID_NODE, bits,
						    READ_PIN_FROM_PHANDLE) };

		if (sizeof(bits) == 0)
			return (uint32_t)-1;

		sku_id = CONVERT_NUMERAL_SYSTEM(
			DT_STRING_TOKEN(SKU_GPIO_ID_NODE, system), bits,
			ARRAY_SIZE(bits));
	}

	return sku_id;
}

#endif

#define BOARD_GPIO_ID_NODE DT_NODELABEL(gpio_id_board)
#if DT_NODE_HAS_STATUS(SKU_GPIO_ID_NODE, okay)

__override int board_get_version(void)
{
	static int board_version = -1;

	if (board_version == -1) {
		int bits[] = { DT_FOREACH_PROP_ELEM(BOARD_GPIO_ID_NODE, bits,
						    READ_PIN_FROM_PHANDLE) };

		if (sizeof(bits) == 0)
			return -1;

		board_version = CONVERT_NUMERAL_SYSTEM(
			DT_STRING_TOKEN(BOARD_GPIO_ID_NODE, system), bits,
			ARRAY_SIZE(bits));
	}

	return board_version;
}

#endif

BUILD_ASSERT(DT_NODE_HAS_STATUS(SKU_GPIO_ID_NODE, okay) ||
		     DT_NODE_HAS_STATUS(BOARD_GPIO_ID_NODE, okay),
	     "neither sku or board id nodelabels found");
